/*Copyright (C) 2019 Centro de Computacao Cientifica e Software Livre
Departamento de Informatica - Universidade Federal do Parana

This file is part of Plataforma Integrada MEC.

Plataforma Integrada MEC is free software: you can redistribute it and/or modify
it under the terms of the GNU Affero General Public License as published by
the Free Software Foundation, either version 3 of the License, or
(at your option) any later version.

Plataforma Integrada MEC is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU Affero General Public License for more details.

You should have received a copy of the GNU Affero General Public License
along with Plataforma Integrada MEC.  If not, see <http://www.gnu.org/licenses/>.*/

import React, { useEffect, useState } from "react";
import moment from "moment";
import styled from "styled-components";
//imports from local files
import TableData from "../../../Components/Components/Table";
import SnackBar from "../../../../Components/SnackbarComponent";
import { Url } from "../../../Filters";
import LoadingSpinner from "../../../../Components/LoadingSpinner";
import {
  getRequest,
  postRequest,
} from "../../../../Components/HelperFunctions/getAxiosConfig";
import MobileList from "../../../Components/Components/MobileComponents/SimpleList";
import MobilePageHeader from "../../../Components/Components/MobileComponents/MobilePageHeader";
import PageHeader from "../../../Components/Components/PageHeader";
import { apiDomain } from '../../../../env';
//imports from material ui
import { withStyles } from "@material-ui/core/styles";
import TableBody from "@material-ui/core/TableBody";
import TableCell from "@material-ui/core/TableCell";
import MenuItem from "@material-ui/core/MenuItem";
import TableRow from "@material-ui/core/TableRow";
import TextField from "@material-ui/core/TextField";
import IconButton from "@material-ui/core/IconButton";
import { Button, Paper, Grid } from "@material-ui/core";
import CircularProgress from "@material-ui/core/CircularProgress";
import AddRoundedIcon from "@material-ui/icons/AddRounded";
import UpdateRoundedIcon from "@material-ui/icons/UpdateRounded";
import FilterListRoundedIcon from "@material-ui/icons/FilterListRounded";
import VisibilityIcon from "@material-ui/icons/Visibility";
import CheckRoundedIcon from "@material-ui/icons/CheckRounded";
import CloseRoundedIcon from "@material-ui/icons/CloseRounded";
import EmailRoundedIcon from '@material-ui/icons/EmailRounded';
//routers
import { Link } from "react-router-dom";

//Image Import
import { noAvatar } from "ImportImages.js";


const StyledTableCell = withStyles((theme) => ({
  head: {
    backgroundColor: theme.palette.common.black,
    color: theme.palette.common.white,
  },
  body: {
    fontSize: 14,
  },
}))(TableCell);

const StyledTableRow = withStyles((theme) => ({
  root: {
    "&:nth-of-type(odd)": {
      backgroundColor: theme.palette.action.hover,
    },
  },
}))(TableRow);

const AproveTeacher = () => {
  const WINDOW_WIDTH = window.innerWidth
  const ADD_ONE_LENGHT = [""];
  const TOP_LABELS = [
    "ESTADO DO PEDIDO",
    "ID",
    "NOME",
    "EMAIL",
    "PEDIDO EM(MM/DD/YYYY)",
    "VISUALIZAR",
    "AÇÕES",
  ]; //Labels from Table

  const [invertList, setInvertList] = useState(false)
  const [error, setError] = useState(null); //Necessary to consult the API, catch errors
  const [isLoaded, setIsLoaded] = useState(false); //Necessary to consult the API, wait until complete
  const [items, setItems] = useState([]); //Necessary to consult the API, data

  const [isLoadingMoreItems, setIsLoadingMoreItems] = useState(false); //controlls the state of loadind more data
  const [currPage, setCurrPage] = useState(0)
  const [showFilter, setShowFilter] = useState(false);

  const [option, setOption] = useState("requested");
  const [name, setName] = useState("");
  const [nameValue, setNameValue] = useState("")
  const [email, setEmail] = useState("");
  const [emailValue, setEmailValue] = useState("")

  const [snackInfo, setSnackInfo] = useState({
    message: "",
    icon: "",
    open: false,
    color: "",
  });

  const StateOptions = [
    { name: "requested", value: "Pendente" },
    { name: "accepted", value: "Aceito" },
    { name: "rejected", value: "Rejeitado" },
  ];

  //handle snack info
  const HandleSnack = (message, state, icon, color) => {
    setSnackInfo({
      message: message,
      icon: icon,
      open: state,
      color: color,
    });
  };

  const handleChange = (e, type) => {
    const value = e.target.value;
    setOption(value);
  };

  const NameHandler = (e) => {
    setNameValue(e.target.value)
  };

  const EmailHandler = (e) => {
    setEmailValue(e.target.value)
  };

  const removeItemFromList = (itemId) => {
    let index = -1;
    for (let i = 0; i < items.length; i++) {
      const element = items[i];
      if (element.id === itemId) {
        index = i
        break
      }
    }
    if (index !== -1) {
      const cpyItems = [...items]
      cpyItems.splice(index, 1)
      setItems(cpyItems)
    }
  }

  const ComplaintStatus = (status) => {
    switch (status) {
      case "accepted":
        return (
          <Paper
            style={{
              textAlign: "center",
              padding: "0.5em",
              backgroundColor: "#228B22",
              fontWeight: "500",
              color: "#FFFAFA",
            }}
          >
            ACEITO
          </Paper>
        );
      case "requested":
        return (
          <Paper
            style={{
              textAlign: "center",
              padding: "0.5em",
              backgroundColor: "#FF8C00",
              fontWeight: "500",
              color: "#FFFAFA",
            }}
          >
            PENDENTE
          </Paper>
        );
      case "rejected":
        return (
          <Paper
            style={{
              textAlign: "center",
              padding: "0.5em",
              backgroundColor: "#FA8072",
              fontWeight: "500",
              color: "#FFFAFA",
            }}
          >
            Rejeitado
          </Paper>
        );
      default:
        return (
          <Paper
            style={{
              textAlign: "center",
              padding: "0.5em",
              backgroundColor: "#797D7F ",
              fontWeight: "500",
              color: "#FFFAFA",
            }}
          >
            Não requisitado
          </Paper>
        );
    }
  };

  const DisplayDate = (date) => {
    const convertedData = moment.utc(date);
    return moment(convertedData)
      .format("LLL")
      .toString();
  };

  const handleAprove = (userId, userName) => {
    const url = `/users/${userId}/add_teacher`;
    const body = {
      approves: true,
    };
    postRequest(
      url,
      body,
      (data) => {
        if (data.errors) HandleSnack("Erro!", true, "warning", "#FA8072");
        else {
          HandleSnack(
            `${userName} aceito como professor!`,
            true,
            "success",
            "#228B22"
          );
          setCurrPage(0)
          removeItemFromList(userId)
        }
      },
      (error) => {
        HandleSnack("Erro!", true, "warning", "#FA8072");
      }
    );
  };

  const handleReject = (userId, userName) => {
    const url = `/users/${userId}/add_teacher`;
    const body = {
      approves: false,
    };
    postRequest(
      url,
      body,
      (data) => {
        if (data.errors) HandleSnack("Erro!", true, "warning", "#FA8072");
        else {
          HandleSnack(
            `${userName} rejeitado como professor!`,
            true,
            "success",
            "#228B22"
          );
          setCurrPage(0)
          removeItemFromList(userId)
        }
      },
      (error) => {
        HandleSnack("Erro!", true, "warning", "#FA8072");
      }
    );
  };

  const cleanArrayAndInvert = () => {
    setInvertList(!invertList)
    setCurrPage(0)
    setItems([])
  }

  const buildUrl = (email, submitter_request, name, direction) => {
    if (email && submitter_request && name)
      return Url("users", `"submitter_request" : "${submitter_request}", "email" : "${email}", "name" : "${name}"`, currPage, direction)

    else if (email && name)
      return Url("users", `"email" : "${email}", "name" : "${name}"`, currPage, direction)
    else if (email && submitter_request)
      return Url("users", `"email" : "${email}", "submitter_request" : "${submitter_request}"`, currPage, direction)
    else if (name && submitter_request)
      return Url("users", `"name" : "${name}", "submitter_request" : "${submitter_request}"`, currPage, direction)

    else if (email)
      return Url("users", `"email" : "${email}"`, currPage, direction)
    else if (submitter_request)
      return Url("users", `"submitter_request" : "${submitter_request}"`, currPage, direction)
    else if (name)
      return Url("users", `"name" : ${name}`, currPage, direction)
    else
      return Url("users", "", currPage, direction)
  }

  useEffect(() => {
    if (currPage === 0)
      setIsLoaded(false)
    else
      setIsLoadingMoreItems(true)
    getRequest(
      buildUrl(email, option, name, invertList ? "ASC" : "DESC"),
      (data, header) => {
        const arrData = [...data]
        if (arrData.length === 0) {
          HandleSnack('Não há mais dados para serem carregados', true, 'warning', '#FFC125')
        } else {
          const arrItems = [...items]
          if (currPage === 0) {
            setItems(arrData.concat(ADD_ONE_LENGHT))
          }
          else {
            arrItems.pop(); //Deleting the last position, that was used to display the button of load more items 
            const arrResult = arrItems.concat(arrData)
            setItems(arrResult.concat(ADD_ONE_LENGHT))
          }
        }
        setIsLoaded(true)
        setIsLoadingMoreItems(false)
      },
      (error) => {
        HandleSnack('Erro ao carregar os dados', true, 'warning', '#FA8072')
        setIsLoadingMoreItems(false)
        setIsLoaded(true)
        setError(true)
      }
    )
  }, [currPage, option, email, name, invertList])

  useEffect(() => {
    setOption("requested")
    setName("")
    setNameValue("")
    setEmail("")
    setEmailValue("")
  }, [showFilter])

  if (error) {
    return <div>Error: {error.message}</div>;
  } else if (!isLoaded) {
    return <LoadingSpinner text="Carregando..." />;
  } else {
    if (WINDOW_WIDTH <= 1130) {
      return (
        <>
          <SnackBar
            severity={snackInfo.icon}
            text={snackInfo.message}
            snackbarOpen={snackInfo.open}
            color={snackInfo.color}
            handleClose={() =>
              setSnackInfo({
                message: "",
                icon: "",
                open: false,
                color: "",
              })
            }
          />
          <MobilePageHeader
            title="Aprovação de professores"
            actions={[
              {
                name: "Atualizar",
                isLoading: false,
                func: () => {
                  setCurrPage(0)
                },
                icon: <UpdateRoundedIcon />
              },
              {
                name: "Filtrar",
                isLoading: false,
                func: () => {
                  setShowFilter(!showFilter);
                },
                icon: <FilterListRoundedIcon />
              },
              {
                name: "Inverter lista",
                isLoading: false,
                func: () => {
                  cleanArrayAndInvert()
                },
              }
            ]}
          >
            {showFilter ? (
              <>
                <div style={{ height: "1em" }}></div>
                {showFilter ? (
                  <Grid
                    container
                    direction="row"
                    justify="space-between"
                    alignItems="center"
                    alignContent="flex-end"
                    spacing={3}
                    xs={12}
                  >
                    <Grid item>
                      <TextField
                        select
                        label="Estado"
                        value={option ? option : ""}
                        onChange={handleChange}
                        helperText="Por favor, selecione uma das opções"
                      >
                        {StateOptions.map((option, index) => (
                          <MenuItem
                            key={option.value}
                            value={option.name}
                            name={option.value}
                          >
                            {option.value}
                          </MenuItem>
                        ))}
                      </TextField>
                    </Grid>
                    <Grid item>
                      <TextField
                        label="Nome"
                        onChange={NameHandler}
                        value={nameValue}
                        onBlur={(event) => { setName(event.target.value) }}
                        helperText="Retire o foco do campo de texto ao terminar de digitar"
                      />
                    </Grid>
                    <Grid item>
                      <TextField
                        label="Email"
                        onChange={EmailHandler}
                        value={emailValue}
                        onBlur={(event) => { setEmail(event.target.value) }}
                        helperText="Retire o foco do campo de texto ao terminar de digitar"
                      />
                    </Grid>
                  </Grid>
                ) : null}
              </>
            ) : null}
          </MobilePageHeader>

          <div style={{ height: "2em" }}></div>

          {items.map((row, index) =>
            index === items.length - 1 ? (
              <StyledDivButton>
                <Button
                  key={new Date().toISOString() + row.created_at}
                  color="primary"
                  variant="text"
                  // disabled={isLoadingMoreItems}
                  startIcon={<AddRoundedIcon />}
                  disabled={isLoadingMoreItems}
                  onClick={() => {
                    setCurrPage(currPage + 1)
                  }}
                >
                  {isLoadingMoreItems ? (
                    <CircularProgress size={24} />
                  ) : (
                      "Carregar mais itens"
                    )}
                </Button>
              </StyledDivButton>
            ) : (
                <>
                  <MobileList
                    key={new Date().toISOString() + row.created_at}
                    title={row.name}
                    subtitle={row.id}
                    backColor={"#00bcd4"}
                    avatar={
                      <img
                        src={row.avatar ? apiDomain + row.avatar : noAvatar}
                        alt="user avatar"
                        style={{
                          height: "100%",
                          width: "100%",
                          borderRadius: "50%",
                        }}
                      />
                    }
                    href={`/admin/user?id=${row.id}`}
                    reset={() => {

                    }}
                    data={[
                      {
                        title: "Email",
                        subtitle: row.email ?
                          <Link to={`/admin/sendEmail?email=${row.email}`} style={{ textDecoration: 'none' }}>
                            <Button
                              variant='text'
                              color='primary'
                              startIcon={<EmailRoundedIcon />}
                            >
                              {row.email}
                            </Button>
                          </Link> : null

                      },
                      {
                        title: "Pedido em",
                        subtitle: DisplayDate(row.created_at),
                      },
                      {
                        title: "Situação do pedido",
                        subtitle: ComplaintStatus(row.submitter_request),
                      },
                      {
                        title: "Ações rápidas",
                        subtitle: <>
                          <Button
                            variant="contained"
                            color="secondary"
                            style={{ width: "100%" }}
                            disabled={
                              row.submitter_request === "requested" ? false : true
                            }
                            startIcon={
                              <CloseRoundedIcon style={{ fill: "#FFFAFA" }} />
                            }
                            onClick={() => {
                              handleReject(row.id, row.name);
                            }}
                          >
                            Recusar
                                                    </Button>
                          <div style={{ height: "0.5em" }} />
                          <Button
                            variant="contained"
                            color="primary"
                            style={{ width: "100%" }}
                            disabled={
                              row.submitter_request === "requested" ? false : true
                            }
                            startIcon={
                              <CheckRoundedIcon style={{ fill: "#FFFAFA" }} />
                            }
                            onClick={() => {
                              handleAprove(row.id, row.name);
                            }}
                          >
                            Aceitar
                                                    </Button>
                        </>
                      }
                    ]}
                  />
                  <div style={{ height: "0.5em" }} />
                </>
              )
          )}
        </>
      );
    } else {
      return (
        <>
          <SnackBar
            severity={snackInfo.icon}
            text={snackInfo.message}
            snackbarOpen={snackInfo.open}
            color={snackInfo.color}
            handleClose={() =>
              setSnackInfo({
                message: "",
                icon: "",
                open: false,
                color: "",
              })
            }
          />

          <PageHeader
            title="Aprovação de professores"
            actions={[
              {
                name: "Atualizar",
                isLoading: false,
                func: () => {
                  setCurrPage(0)
                },
                icon: <UpdateRoundedIcon />
              },
              {
                name: "Filtrar",
                isLoading: false,
                func: () => {
                  setShowFilter(!showFilter);
                },
                icon: <FilterListRoundedIcon />
              }
            ]}
          >
            {showFilter ? (
              <>
                <div style={{ height: "1em" }}></div>
                {showFilter ? (
                  <Grid
                    container
                    direction="row"
                    justify="space-between"
                    alignItems="center"
                    alignContent="flex-end"
                    spacing={3}
                    xs={12}
                  >
                    <Grid item>
                      <TextField
                        select
                        label="Estado"
                        value={option ? option : ""}
                        onChange={handleChange}
                        helperText="Por favor, selecione uma das opções"
                      >
                        {StateOptions.map((option, index) => (
                          <MenuItem
                            key={option.value}
                            value={option.name}
                            name={option.value}
                          >
                            {option.value}
                          </MenuItem>
                        ))}
                      </TextField>
                    </Grid>
                    <Grid item>
                      <TextField
                        label="Nome"
                        onChange={NameHandler}
                        value={nameValue}
                        onBlur={(event) => { setName(event.target.value) }}
                        helperText="Retire o foco do campo de texto ao terminar de digitar"
                      />
                    </Grid>
                    <Grid item>
                      <TextField
                        label="Email"
                        onChange={EmailHandler}
                        value={emailValue}
                        onBlur={(event) => { setEmail(event.target.value) }}
                        helperText="Retire o foco do campo de texto ao terminar de digitar"
                      />
                    </Grid>
                  </Grid>
                ) : null}
              </>
            ) : null}
          </PageHeader>

          <div style={{ height: "2em" }}></div>

          <Grid xs={12} container>
            <TableData
              top={TOP_LABELS}
              onIconPressed={cleanArrayAndInvert}
            >
              <TableBody>
                {items.map((row, index) =>
                  index === items.length - 1 ? (
                    <StyledTableRow key={new Date().toISOString() + row.created_at}>
                      {/* Button to load more data */}
                      <StyledTableCell>
                        <Button
                          color="primary"
                          variant="text"
                          // disabled={isLoadingMoreItems}
                          startIcon={<AddRoundedIcon />}
                          disabled={isLoadingMoreItems}
                          onClick={() => {
                            setCurrPage(currPage + 1)
                          }}
                        >
                          {isLoadingMoreItems ? (
                            <CircularProgress size={24} />
                          ) : (
                              "Carregar mais itens"
                            )}
                        </Button>
                      </StyledTableCell>
                    </StyledTableRow>
                  ) : (
                      <StyledTableRow
                        key={new Date().toISOString() + index}
                        style={{ flex: 1, width: "100%" }}
                      >
                        <StyledTableCell component="th" scope="row">
                          {ComplaintStatus(row.submitter_request)}
                        </StyledTableCell>
                        <StyledTableCell align="right">{row.id}</StyledTableCell>
                        <StyledTableCell align="right">
                          {row.name}
                        </StyledTableCell>
                        <StyledTableCell align="right">
                          {row.email}
                        </StyledTableCell>
                        <StyledTableCell align="right">
                          {DisplayDate(row.created_at)}
                        </StyledTableCell>
                        <StyledTableCell align="right">
                          <Link to={`/admin/user?id=${row.id}`}>
                            <IconButton>
                              <VisibilityIcon style={{ fill: "#00bcd4" }} />
                            </IconButton>
                          </Link>
                        </StyledTableCell>
                        <StyledTableCell align="right">
                          <Button
                            variant="contained"
                            color="secondary"
                            style={{ width: "100%" }}
                            disabled={
                              row.submitter_request === "requested" ? false : true
                            }
                            startIcon={
                              <CloseRoundedIcon style={{ fill: "#FFFAFA" }} />
                            }
                            onClick={() => {
                              handleReject(row.id, row.name);
                            }}
                          >
                            Recusar
                                                    </Button>
                          <div style={{ height: "0.5em" }} />
                          <Button
                            variant="contained"
                            color="primary"
                            style={{ width: "100%" }}
                            disabled={
                              row.submitter_request === "requested" ? false : true
                            }
                            startIcon={
                              <CheckRoundedIcon style={{ fill: "#FFFAFA" }} />
                            }
                            onClick={() => {
                              handleAprove(row.id, row.name);
                            }}
                          >
                            Aceitar
                                                    </Button>
                        </StyledTableCell>
                      </StyledTableRow>
                    )
                )}
              </TableBody>
            </TableData>
          </Grid>
        </>
      );
    }
  }
};
export default AproveTeacher;

const StyledDivButton = styled(Paper)`
  width: 100%;
  display: flex;
  justify-content: center;
  align-items: center;
`;
