import React, { useState, useEffect } from 'react'
import styled from 'styled-components'
import Stepper from '../Stepper.js'
import FormControl from '@material-ui/core/FormControl';
import MenuItem from '@material-ui/core/MenuItem';
import { Button } from '@material-ui/core'
import { RightSideStrikedH3, LeftSideStrikedH3 } from '../LoginContainerFunction.js'
import { ButtonCancelar } from './PartTwo.js'
import axios from 'axios'
import FormInput from '../FormInput.js'
import TextField from '@material-ui/core/TextField';
import { makeStyles } from "@material-ui/styles";


const useStyles = makeStyles(theme => ({
    darkTextField: {
        maxWidth: "100%",
        fontSize: "15px",
        fontWeight: "lighter",
        color: "white",
        width: "100%"
    },
    lightTextField: {
        maxWidth: "100%",
        fontSize: "15px",
        fontWeight: "lighter",
        color: "black",
        width: "100%"
    }
}));

export function sortDict(dict) {
    const newDict = dict.sort((a, b) => (a.name) > (b.name) ? 1 : -1)
    return newDict

}

const extractUFInfo = (ufs, name) => {
    var id = ''
    var abbreviation = ''
    for (const obj of ufs) {
        if (obj.name === name) {
            id = obj.id
            abbreviation = obj.abbreviation
        }
    }
    return { id: id, abbreviation: abbreviation }
}

export default function PartOne(props) {
    const classes = useStyles();
    //stores initial get response (list of states, sorted alphabetically)
    const [ufList, setStates] = useState([])
    const handleSetStates = (states) => { setStates(states) }

    //stores list of cities sorted alphabetically
    const [municipioList, setMunicipioList] = useState([])
    const handleSetMunicipioList = (municipios) => setMunicipioList(municipios)

    //stores a single user selected state
    const [uf, setUF] = useState(
        {
            algumFoiEscolhido: false,
            name: '',
            abbreviation: ''
        }
    )

    //stores a single user selected city
    const [municipio, setMunicipio] = useState(
        {
            algumFoiEscolhido: false,
            name: ''
        }
    )

    const [codigoINEP, setCodigoINEP] = useState(
        {
            codigoInvalido: false,
            value: ''
        }
    )

    const handleCodigoINEP = (event) => {
        const code = event.target.value

        setCodigoINEP({
            ...codigoINEP,
            codigoInvalido: false,
            value: code
        })
    }

    const validateINEP = () => {
        const code = codigoINEP.value

        axios.get(('https://www.simcaq.c3sl.ufpr.br/api/v1/portal_mec_inep?filter=school_cod:' + code)
        ).then((response) => {
            handleSubmit()
        }, (error) => {
            setCodigoINEP({
                ...codigoINEP,
                codigoInvalido: true,
                value: ''
            })
        }
        )
    }

    const handleSubmit = () => {
        props.handleBuscar(uf.abbreviation, uf.name, municipio.name, codigoINEP.value)
    }

    //on render component, call simcaq api and update ufList
    useEffect(() => {
        axios.get(('https://simcaq.c3sl.ufpr.br/api/v1/state')
        ).then((response) => {
            console.log(sortDict(response.data.result))
            handleSetStates(sortDict(response.data.result))
        },
            (error) => console.log('erro acessando api do simcaq (estados)'))
    }, [])

    const handleChooseUF = (event) => {
        const ufName = event.target.value
        const { id, abbreviation } = extractUFInfo(ufList, ufName)
        console.log(id, abbreviation)

        setUF({
            ...uf,
            algumFoiEscolhido: true,
            name: ufName,
            abbreviation: abbreviation
        }
        )

        axios.get(('https://simcaq.c3sl.ufpr.br/api/v1/city?filter=state:' + id)
        ).then((response) => {
            handleSetMunicipioList(sortDict(response.data.result))
        }, (error) => console.log('erro acessando api do simcaq (cidades)')
        )
    }

    const handleChooseCity = (event) => {
        const cityName = event.target.value
        console.log(cityName)
        setMunicipio({
            ...municipio,
            algumFoiEscolhido: true,
            name: cityName
        }
        )
    }

    return (
        <>
            {/*/////////////////////////////PRIMEIRA PARTE/////////////////////////////*/}
            <Content>
                <h4>Vamos localizar o seu cadastro:</h4>
                <Stepper contrast={props.contrast} activeStep={props.activeStep}/>
                <form style={{ textAlign: "start" }}>
                    <p>Localize pelo menos uma escola em que você tenha atuado até maio de 2017:</p>
                    <FormControl required style={{ width: "100%", marginTop: '1em' }}>
                        <h5> Procure sua UF </h5>
                        <StyledTextField
                            helperText={<span style={props.contrast === "" ? {} : { color: "white" }}>Clique aqui para selecionar sua UF</span>}
                            contrast={props.contrast}
                            select
                            fullWidth
                            value={uf.name}
                            onChange={handleChooseUF}
                            variant="outlined"
                            InputProps={props.contrast === "" ? { className: classes.lightTextField } : { className: classes.darkTextField }}
                        >
                            {
                                ufList.map((ufs) =>
                                    <MenuItem style={props.contrast === "" ? {} : { backgroundColor: "black", color: "yellow", textDecoration: "underline" }} key={ufs.name} value={ufs.name}>{ufs.name}</MenuItem>
                                )
                            }
                        </StyledTextField>
                    </FormControl>
                    <FormControl required style={{ width: "100%", marginTop: '1em' }}>
                        <h5> Busque o seu município </h5>
                        <StyledTextField
                            helperText={<span style={props.contrast === "" ? {} : { color: "white" }}>Clique aqui para selecionar seu município</span>}
                            contrast={props.contrast}
                            select
                            fullWidth
                            value={municipio.name}
                            onChange={handleChooseCity}
                            variant="outlined"
                            InputProps={props.contrast === "" ? { className: classes.lightTextField } : { className: classes.darkTextField }}
                        >
                            {
                                municipioList.map((cidades) =>
                                    <MenuItem style={props.contrast === "" ? {} : { backgroundColor: "black", color: "yellow", textDecoration: "underline" }} key={cidades.name} value={cidades.name}>{cidades.name}</MenuItem>
                                )
                            }
                        </StyledTextField>
                    </FormControl>
                    <div style={{ display: "flex", justifyContent: "center", paddingTop: "10px", paddingBottom: "10px" }}>
                        <ButtonConfirmar
                            contrast={props.contrast}
                            onClick={((uf.algumFoiEscolhido && municipio.algumFoiEscolhido) ? handleSubmit : '')}
                        >
                            BUSCAR</ButtonConfirmar>
                    </div>
                </form>
            </Content>

            <div style={{ display: "flex", justifyContent: "center", alignItems: "center" }}>
                <LeftSideStrikedH3 contrast={props.contrast} /><StrikeSpan>ou</StrikeSpan><RightSideStrikedH3 contrast={props.contrast} />
            </div>

            {/*/////////////////////////////SEGUNDA PARTE/////////////////////////////*/}
            <Content>
                <form>
                    <p>Localize pelo código INEP da escola:</p>
                    <FormControl required style={{ width: "100%" }}>
                        <FormInput
                            contrast={props.contrast}
                            inputType={'text'}
                            name={'Código INEP'}
                            value={codigoINEP.value}
                            handleChange={handleCodigoINEP}
                            placeholder={'Código INEP'}
                            required={true}
                            error={codigoINEP.codigoInvalido}
                            help={codigoINEP.codigoInvalido ? <span style={{ color: 'red' }}>código INEP inválido</span> : ''}
                        >
                        </FormInput>
                    </FormControl>
                    <div style={{ display: "flex", justifyContent: "center", paddingTop: "10px", paddingBottom: "10px" }}>
                        <ButtonConfirmar
                            contrast={props.contrast}
                            onClick={validateINEP}
                        >
                            BUSCAR</ButtonConfirmar>
                    </div>
                </form>
            </Content>
            <hr style={props.contrast === "" ? { color: "#666" } : { color: "white" }} />
            <ButtonsArea>
                <ButtonCancelar contrast={props.contrast} onClick={props.handleCancelar}>CANCELAR VERIFICAÇÃO</ButtonCancelar>
            </ButtonsArea>
        </>
    )
}

const StyledTextField = styled(TextField)`
    .MuiOutlinedInput-root {
        &.Mui-focused fieldset {
            border-color: ${props => props.contrast === "" ? "#00bcd4" : "yellow"};
        }
        fieldset {
            border-color: ${props => props.contrast === "" ? "#666" : "white"};
        }
    }
`

export const ButtonsArea = styled.div`
    display : flex;
    justify-content : center;
    padding-top : 10px;
    padding-bottom : 10px;
`

const StrikeSpan = styled.span`
    vertical-align : middle;
    font-family : Roboto;
    font-style : normal;
    font-weight : 500;
    line-height : 22px;
    font-size : 15px;
    letter-spacing : .01em;
`

export const Content = styled.div`
    margin-top : 16px;
    margin-bottom : 16px;
    margin-right : 10%;
    margin-left : 10%;

    h4 {
        text-align : center;
        magin-bottom : 20px;
        font-family: Roboto;
        font-style : normal;
        font-weight : 300;
        line-height : 36px;
        font-size : 26px;
        margin-top : 20px;
    }

    p {
        font-family : Roboto;
        font-style : normal;
        font-weight : 400;
        line-height : 21px;
        font-size : 15px;
    }
`
export const ButtonConfirmar = styled(Button)`
    :hover{
        background: ${props => props.contrast === "" ? "" : "rgba(255,255,0,0.24) !important"};
    }
    background: ${props => props.contrast === "" ? "#00bcd4 !important" : "black !important"};
    border: ${props => props.contrast === "" ? "0 !important" : "1px solid white !important"};
    color: ${props => props.contrast === "" ? "#fff !important" : "yellow !important"};
    text-decoration: ${props => props.contrast === "" ? "none !important" : "underline !important"};
    font-family : 'Roboto',sans-serif !important;
    outline : none !important;
    margin : 6px 8px !important;
    white-space : nowrap !important;
    text-transform : uppercase !important;
    font-weight : bold !important;
    cursor : pointer !important;
    text-align : center !important;
`
