import React, { useState } from 'react'
import { Content } from './PartOne.js'
import { ButtonCancelar, ButtonGrey } from './PartTwo.js'
import FormControl from '@material-ui/core/FormControl';
import Stepper from '../Stepper.js'
import FormInput from '../FormInput.js'
import styled from 'styled-components'
import { Button } from '@material-ui/core'

export default function PartThree(props) {
    const [phoneNumber, setPhoneNumber] = useState(
        {
            flagInvalid: false,
            number: ''
        }
    )
    const handleChangePhoneNumber = (event) => {
        const input = event.target.value;
        setPhoneNumber({
            ...phoneNumber,
            flagInvalid: (input.length < 10 ? true : false),
            number: (input.length > 10 ? phoneNumber.number : input),
        })
    }

    const [cpf, setCpf] = useState({
        flagInvalid: false,
        number: ''
    })
    const handleChangeCpf = (event) => {
        const input = event.target.value;
        setCpf({
            ...cpf,
            flagInvalid: (input.length < 11 ? true : false),
            number: (input.length > 11 ? cpf.number : input),
        })
    }

    const handleSubmit = () => {
        const submit_phone = phoneNumber.number
        const submit_cpf = cpf.number

        props.handleSubmit(submit_phone, submit_cpf)
    }

    return (
        <>
            <Content>
                <h4>Vamos localizar o seu cadastro:</h4>
                <Stepper contrast={props.contrast} activeStep={props.activeStep}/>
                <form style={{ textAlign: "start" }}>
                    <FormControl required style={{ width: "100%" }}>
                        <p>Inserir o telefone da escola:</p>
                        <FormInput
                            contrast={props.contrast}
                            variant='outlined'
                            inputType={'text'}
                            pattern="[0-9]"
                            name={'DDD e Número'}
                            placeholder={'Exemplo: 4112345678'}
                            value={phoneNumber.number}
                            handleChange={handleChangePhoneNumber}
                            error={phoneNumber.flagInvalid}
                        >
                        </FormInput>
                    </FormControl>
                    <FormControl required style={{ width: "100%" }}>
                        <p>Inserir o seu CPF</p>
                        <FormInput
                            contrast={props.contrast}
                            variant='outlined'
                            inputType={'text'}
                            name={'11 dígitos'}
                            placeholder={'11 dígitos'}
                            value={cpf.number}
                            handleChange={handleChangeCpf}
                            mask={'999.999.999-99'}
                            error={cpf.flagInvalid}
                        >
                        </FormInput>
                    </FormControl>
                    <div style={{ display: "flex", justifyContent: "space-evenly", paddingTop: "10px", paddingBottom: "10px" }}>
                        <div style={{ display: "flex", justifyContent: "center" }}>
                            <ButtonConfirmar contrast={props.contrast} onClick={((cpf.flagInvalid || phoneNumber.flagInvalid) ? () => { console.log('cpf.flagInvalid: ', cpf.flagInvalid, 'phoneNumber.flagInvalid: ', phoneNumber.flagInvalid) } : handleSubmit)}>BUSCAR</ButtonConfirmar>
                        </div>
                        <div style={{ display: "flex", justifyContent: "center" }}>
                            <ButtonGrey contrast={props.contrast} onClick={() => props.goBack(false, true, false)}>VOLTAR</ButtonGrey>
                            <ButtonCancelar contrast={props.contrast} onClick={props.handleCancelar}>CANCELAR</ButtonCancelar>
                        </div>
                    </div>
                </form>
            </Content>
        </>
    )
}

const ButtonConfirmar = styled(Button)`
    :hover{
        background: ${props => props.contrast === "" ? "" : "rgba(255,255,0,0.24) !important"};
    }
    background: ${props => props.contrast === "" ? "#00bcd4 !important" : "black !important"};
    border: ${props => props.contrast === "" ? "0 !important" : "1px solid white !important"};
    color: ${props => props.contrast === "" ? "#fff !important" : "yellow !important"};
    text-decoration: ${props => props.contrast === "" ? "none !important" : "underline !important"};
    font-family : 'Roboto',sans-serif !important;
    outline : none !important;
    margin : 6px 8px !important;
    white-space : nowrap !important;
    text-transform : uppercase !important;
    font-weight : bold !important;
    cursor : pointer !important;
    text-align : center !important;
`
