import React, { useEffect, useState } from 'react';
import { withStyles } from '@material-ui/core/styles';
import Table from '@material-ui/core/Table';
import TableBody from '@material-ui/core/TableBody';
import TableCell from '@material-ui/core/TableCell';
import TableContainer from '@material-ui/core/TableContainer';
import TableHead from '@material-ui/core/TableHead';
import TableRow from '@material-ui/core/TableRow';
import Paper from '@material-ui/core/Paper';

const StyledTableCell = withStyles(theme => ({
  head: {
    backgroundColor: '#00bcd4',
    color: '#ffffff',
    fontFamily: 'Roboto',
    fontStyle: 'normal',
    fontWeight: 500,
    fontSize: 15,
    letterSpacing: .01
  },
  body: {
    fontSize: 14,
  },
}))(TableCell);

const ContrastStyledTableCell = withStyles(theme => ({
  head: {
    backgroundColor: 'black',
    color: '#ffffff',
    border: '1px solid white',
    fontFamily: 'Roboto',
    fontStyle: 'normal',
    fontWeight: 500,
    fontSize: 15,
    letterSpacing: .01
  },
  body: {
    fontSize: 14,
  },
}))(TableCell);

const ContrastStyledTableCellBody = withStyles(theme => ({
  body: {
    fontSize: 14,
    backgroundColor: 'black',
    color: '#ffffff',
    border: '1px solid white',
    fontFamily: 'Roboto',
    fontStyle: 'normal',
    fontWeight: 500,
    letterSpacing: .01
  },
}))(TableCell);



export default function CustomizedTables(props) {
  const [columns, setColumns] = useState([]);

  const onClick = (row) => {
    const { city_name, id, name, state_name } = row
    props.onClickTable(city_name, id, name, state_name)
  }

  useEffect(() => {
    const updatedColumns = [...props.columns]; 
    updatedColumns.splice(2, 2); 
    setColumns(updatedColumns);
  }, [])

  return (
    <>
      <TableContainer component={Paper}>
        <Table aria-label="customized table">
          <TableHead>
            <TableRow>
              {
                columns.map((column) =>
                  props.contrast === "" ?
                    <StyledTableCell align="left">{column}</StyledTableCell>
                    :
                    <ContrastStyledTableCell align="left">{column}</ContrastStyledTableCell>
                )
              }
            </TableRow>
          </TableHead>
          <TableBody>
            {
              props.contrast === "" ?
                props.rows.map((row) => {
                  return <TableRow onClick={() => onClick(row)} key={row.id}>
                    <StyledTableCell component="th" scope="row">
                      {row.id}
                    </StyledTableCell>
                    <StyledTableCell align="left">{row.name}</StyledTableCell>
                    {/* <StyledTableCell align="left">{row.state_name}</StyledTableCell>
                    <StyledTableCell align="left">{row.city_name}</StyledTableCell> */}
                  </TableRow>
                })
                :
                props.rows.map((row) => {
                  return <TableRow onClick={() => onClick(row)} key={row.id}>
                    <ContrastStyledTableCellBody component="th" scope="row">
                      {row.id}
                    </ContrastStyledTableCellBody>
                    <ContrastStyledTableCellBody align="left">{row.name}</ContrastStyledTableCellBody>
                    {/* <ContrastStyledTableCellBody align="left">{row.state_name}</ContrastStyledTableCellBody>
                    <ContrastStyledTableCellBody align="left">{row.city_name}</ContrastStyledTableCellBody> */}
                  </TableRow>
                })
            }
          </TableBody>
        </Table>
      </TableContainer>
    </>
  );
}


