/*Copyright (C) 2019 Centro de Computacao Cientifica e Software Livre
Departamento de Informatica - Universidade Federal do Parana

This file is part of Plataforma Integrada MEC.

Plataforma Integrada MEC is free software: you can redistribute it and/or modify
it under the terms of the GNU Affero General Public License as published by
the Free Software Foundation, either version 3 of the License, or
(at your option) any later version.

Plataforma Integrada MEC is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU Affero General Public License for more details.

You should have received a copy of the GNU Affero General Public License
along with Plataforma Integrada MEC.  If not, see <http://www.gnu.org/licenses/>.*/

import React, { useState, useEffect, useContext, useRef } from 'react'
import { Store } from '../../Store.js'
import Grid from '@material-ui/core/Grid';
import ButtonsDiv from './ButtonsDiv.js'
import SobreORecurso from './Forms/SobreORecurso.js'
import NewTitle from './Forms/NewTitle.js'
import Keywords from './Forms/Keywords.js'
import Autor from './Forms/Autor.js'
import TipoDeRecurso from './Forms/TipoDeRecurso.js'
import Idioma from './Forms/Idioma.js'
import { SendInfo } from './SendInfo.js'
import { getRequest } from '../HelperFunctions/getAxiosConfig.js'
import SnackBar from '../../Components/SnackbarComponent';
import LoadingSpinner from '../../Components/LoadingSpinner'

export default function PartOne(props) {
    // {/*const [subjects, setSubjects] = useState([])*/}
    const { state } = useContext(Store)
    const didMountRef = useRef(false);
    const didMountRefObj = useRef(false);

    const [languages, setLanguages] = useState([])
    const [objTypes, setObjTypes] = useState([])

    const [learningObject, setLearningObject] = useState({})

    const [loading, toggleLoading] = useState(true)
    const [loadingObj, toggleLoadingObj] = useState(true)

    const [snackInfo, setSnackInfo] = useState({
        open: false,
        text: '',
        severity: '',
        color: '',
    })

    function handleCloseSnackBar() {
        const info = {
            open: false,
            text: '',
            severity: '',
            color: '',
        }
        handleSnackInfo(info)
    }

    function handleSnackInfo(info) {
        setSnackInfo({
            ...info
        })
    }

    function checkPartOne(data) {
        return (
            data.name !== null &&
            data.tags.length !== 0 &&
            data.author !== null &&
            data.object_type !== null &&
            data.language.length !== 0 &&
            (data.attachments.length !== 0 ||
                data.link !== null)
        )
    }

    function handleSuccessGetObjTypes(data) {
        setObjTypes(data.sort((a, b) => (a.name) > (b.name) ? 1 : -1))
    }

    function handleSuccessGetFormData(data) {
        if (checkPartOne(data)) {
            props.stepperControl(1)
        } else {
            const info = {
                open: true,
                text: 'Preencha todos os campos obrigatórios, inclusive o de "Enviar Recurso"!',
                severity: 'warning',
                color: '#FFC125',
            }
            handleSnackInfo(info)
        }
    }

    function handleSuccessfulGet(data) {
        setLearningObject(data)
    }

    useEffect(() => {
        getRequest(`/object_types/`, handleSuccessGetObjTypes, (error) => { console.log(error) })
        getRequest(`/languages/`, (data) => { setLanguages(data) }, (error) => { console.log(error) })

        const url = `/learning_objects/${props.draftID}`
        getRequest(url, handleSuccessfulGet, (error) => { console.log(error) })
    }, [])

    useEffect(() => {
        if (didMountRef.current) {
            toggleLoading(false)
        }
        else {
            didMountRef.current = true;
        }
    }, [learningObject])

    useEffect(() => {
        if (didMountRefObj.current) {
            toggleLoadingObj(false)
        }
        else {
            didMountRefObj.current = true;
        }
    }, [objTypes])

    const handleSubmit = (e) => {
        e.preventDefault();
        getRequest(`/learning_objects/${props.draftID}`,
            handleSuccessGetFormData,
            () => {
                const info = {
                    open: true,
                    text: 'Não foi possível verificar o status da publicação!',
                    severity: 'error',
                    color: 'red',
                }
                handleSnackInfo(info)
            }
        )
    }

    return (
        <React.Fragment>
            <SnackBar
                snackbarOpen={snackInfo.open}
                handleClose={handleCloseSnackBar}
                severity={snackInfo.severity}
                color={snackInfo.color}
                text={snackInfo.text}
            />
            {
                !loading && !loadingObj ? (
                    <form onSubmit={handleSubmit}>
                        {/*------------------------------Titulo-----------------------------------------*/}
                        <Grid item xs={12} style={{ paddingBottom: "40px" }}>
                            <NewTitle contrast={props.contrast} draftID={props.draftID} onBlurCallback={SendInfo} initialValue={learningObject.name} />
                        </Grid>

                        {/*------------------------------Sobre------------------------------------------*/}
                        <Grid item xs={12} style={{ paddingBottom: "40px" }}>
                            <SobreORecurso contrast={props.contrast} draftID={props.draftID} onBlurCallback={SendInfo} initialValue={learningObject.description} />
                        </Grid>

                        {/*------------------------------Palavras-chave------------------------------------------*/}
                        <Grid item xs={12} style={{ paddingBottom: "40px" }}>
                            <Keywords contrast={props.contrast} draftID={props.draftID} onBlurCallback={SendInfo} initialValue={learningObject.tags !== undefined ? learningObject.tags.map((tag) => tag.name) : null} />
                        </Grid>

                        {/*------------------------------Autor------------------------------------------*/}
                        <Grid item xs={12} style={{ paddingBottom: "40px" }}>
                            <Autor contrast={props.contrast} draftID={props.draftID} onBlurCallback={SendInfo}
                                initialValue={
                                    learningObject.author === state.currentUser.name ?
                                        0 : 1
                                }
                                initialOutroAutor={
                                    learningObject.author !== state.currentUser.name ?
                                        learningObject.author : ''
                                }
                            />
                        </Grid>

                        {/*------------------------------Tipo do Objeto------------------------------------------*/}
                        <Grid item xs={12} style={{ paddingBottom: "40px" }}>
                            <TipoDeRecurso contrast={props.contrast} objTypes={objTypes} draftID={props.draftID} onBlurCallback={SendInfo}
                                initialValue={learningObject.object_type !== undefined && learningObject.object_type !== null ? objTypes.filter((type) => type.name === learningObject.object_type)[0].id : null}
                            />
                        </Grid>

                        {/*------------------------------Idioma------------------------------------------*/}
                        <Grid item xs={12} style={{ paddingBottom: "40px" }}>
                            <Idioma contrast={props.contrast} languages={languages} draftID={props.draftID} onBlurCallback={SendInfo}
                                initialValue={learningObject.language !== undefined ? learningObject.language.map((language) => language.name) : null} initialIDValues={learningObject.language !== undefined ? learningObject.language.map((language) => language.id) : null}
                            />
                        </Grid>

                        {/*------------------------------Botoes------------------------------------------*/}
                        <Grid item xs={12}>
                            <ButtonsDiv contrast={props.contrast} draftID={props.draftID} stepperControl={props.stepperControl} />
                        </Grid>

                        <Grid item xs={12} style={{ marginTop: "20px" }}>
                            <span style={props.contrast === "" ? { marginTop: "20px", fontWeight: "200", color: "#a5a5a5", paddingLeft: "10px" } : { marginTop: "20px", fontWeight: "200", color: "white", paddingLeft: "10px" }}>
                                * Campos obrigatórios
                            </span>
                        </Grid>
                    </form>
                )
                    :
                    (
                        <LoadingSpinner contrast={props.contrast} text={"CARREGANDO"} />
                    )
            }
        </React.Fragment >
    )
}
