/*Copyright (C) 2019 Centro de Computacao Cientifica e Software Livre
Departamento de Informatica - Universidade Federal do Parana

This file is part of Plataforma Integrada MEC.

Plataforma Integrada MEC is free software: you can redistribute it and/or modify
it under the terms of the GNU Affero General Public License as published by
the Free Software Foundation, either version 3 of the License, or
(at your option) any later version.

Plataforma Integrada MEC is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU Affero General Public License for more details.

You should have received a copy of the GNU Affero General Public License
along with Plataforma Integrada MEC.  If not, see <http://www.gnu.org/licenses/>.*/

import React, { useState, useEffect, useContext } from 'react'
import { Store } from '../../Store.js'
import Grid from '@material-ui/core/Grid';
import styled from 'styled-components'
import { apiDomain } from '../../env';
import Stepper from './Stepper.js'
import LoadingSpinner from '../LoadingSpinner.js'
import MoreIcon from '@material-ui/icons/More';
import SdCardIcon from '@material-ui/icons/SdCard';
import DateRangeIcon from '@material-ui/icons/DateRange';
import UpdateIcon from '@material-ui/icons/Update';
import TranslateIcon from '@material-ui/icons/Translate';
import AssignmentIcon from '@material-ui/icons/Assignment';
import { GrayButton, OrangeButton } from './StyledComponents';
import ModalCancelar from './ModalCancelar.js'
import { getDefaultThumbnail } from '../HelperFunctions/getDefaultThumbnail'
import { getRequest } from '../HelperFunctions/getAxiosConfig.js'
import ReCaptcha from 'react-recaptcha'
import Chip from '@material-ui/core/Chip'
import Rating from '@material-ui/lab/Rating';
import StarBorderIcon from '@material-ui/icons/StarBorder';

export default function PartThree(props) {
    var moment = require('moment')
    const { state } = useContext(Store)
    const [loading, setLoading] = useState(false)
    const [unavailableButton, setButtonAvailability] = useState(true);

    const [draft, setDraft] = useState({})
    const [subjects, setSubjects] = useState('')
    const [description, setDescription] = useState('')
    const [author, setAuthor] = useState('')

    function handleSuccess(data) {
        console.log(data.tags)
        console.log(data.language)
        console.log(data.subjects)
        console.log(data)

        setDraft(data)
        /*extract subjects*/
        setSubjects(data.subjects.map((subject) => (subject.name)).join(', '))
        // setTags(data.tags.map(tag => tag.name))
        setDescription(data.description)
        setAuthor(data.author)
        setLoading(false)
    }

    useEffect(() => {
        setLoading(true)
        if (state.currentUser.id !== "") {
            const url = `/learning_objects/${props.draftID}`

            getRequest(url, handleSuccess, (error) => { console.log(error) })

        }
    }, [state.currentUser.id])

    const [modalCancelar, toggleModalCancelar] = useState(false)

    const checkAccessLevel = (levelToCheck) => {
        if (state.currentUser.id !== '') {
            return (checkUserRole(levelToCheck))
        }
    }

    const checkUserRole = (userRole) => {
        return (state.currentUser.roles.filter((role) => role.name === userRole).length > 0)
    }

    function captchaVerified(response) {
        if (response) {
            setButtonAvailability(false)
        }
    }

    return (
        <React.Fragment>
            {
                !loading ?
                    (
                        <React.Fragment>
                            <ModalCancelar
                                contrast={props.contrast}
                                open={modalCancelar}
                                handleClose={() => { toggleModalCancelar(false) }}
                                draftID={draft.id}
                            />
                            <Grid container style={props.contrast === "" ? { backgroundColor: "#f4f4f4" } : { backgroundColor: "black" }}>
                                <Grid item xs={12}>
                                    <StyledSessao1 contrast={props.contrast} className="page-content-preview">
                                        <div className='header'>
                                            <Stepper activeStep={props.activeStep} contrast={props.contrast} />
                                            <h2>Quase lá, agora só falta publicar!</h2>
                                            <span className="subtitle">Veja abaixo como o seu Recurso vai aparecer na Plataforma:</span>
                                        </div>
                                    </StyledSessao1>

                                    <MainContent contrast={props.contrast} >
                                        <CaixaContainer contrast={props.contrast} container spacing={2} className='draft-info'>
                                            <Grid item xs={12} md={4}>
                                                <img alt="" style={{ width: "100%", height: '100%' }}
                                                    src={draft.thumbnail === null ? getDefaultThumbnail(draft.object_type) : apiDomain + draft.thumbnail} />
                                            </Grid>
                                            <Grid item xs={12} md={8}>
                                                <Grid container justify='space-between'>
                                                    <Grid item xs={12}>
                                                        <h3>{draft.name}</h3>
                                                    </Grid>
                                                    <Grid item xs={12}>
                                                        <Grid container spacing={1}>
                                                            <Grid item xs={12}>
                                                                <Rating
                                                                    readOnly
                                                                    name="customized-empty"
                                                                    value={draft.score}
                                                                    precision={0.5}
                                                                    style={props.contrast === "" ? { color: "#666" } : { color: "white" }}
                                                                    emptyIcon={<StarBorderIcon style={props.contrast === "" ? { color: "#666" } : { color: "white" }} fontSize="inherit" />}
                                                                />
                                                            </Grid>
                                                            <Grid item xs={12}>
                                                                Relacionado com: {subjects}
                                                            </Grid>
                                                            <Grid item xs={12}>
                                                                {
                                                                    draft.tags &&
                                                                    draft.tags.map((tag) => {
                                                                        return (
                                                                            <Chip className='tag' key={tag.name} label={tag.name} />
                                                                        )
                                                                    })
                                                                }
                                                            </Grid>
                                                        </Grid>
                                                    </Grid>
                                                </Grid>
                                            </Grid>
                                        </CaixaContainer>
                                    </MainContent>
                                    <MainContent contrast={props.contrast}>
                                        <CaixaContainer contrast={props.contrast} container spacing={2}>
                                            <Grid item xs={12}>
                                                <h1 className='title'>
                                                    Sobre o recurso
                                                </h1>
                                            </Grid>
                                            <Grid item xs={12}>
                                                <hr />
                                            </Grid>
                                            <Grid item xs={12} sm={6}>
                                                <Grid container>
                                                    <Grid item xs={12}>
                                                        {
                                                            description !== '' &&
                                                            <p>
                                                                <b>Descrição:</b>
                                                                <br />
                                                                {description}
                                                            </p>
                                                        }
                                                    </Grid>
                                                    <Grid item xs={12}>
                                                        {
                                                            author !== '' &&
                                                            <p>
                                                                <b>Autoria:</b>
                                                                <br />
                                                                {author}
                                                            </p>
                                                        }
                                                    </Grid>
                                                </Grid>
                                            </Grid>
                                            <Grid item xs={12} sm={6}>
                                                <Grid container spacing={1}>
                                                    <Grid item xs={12}>
                                                        <Grid container direction='row' spacing={1} alignItems='center'>
                                                            <Grid item>
                                                                <MoreIcon />
                                                            </Grid>
                                                            <Grid item>
                                                                <b>Tipo de mídia: </b>{draft.object_type}
                                                            </Grid>
                                                        </Grid>
                                                    </Grid>

                                                    <Grid item xs={12}>
                                                        <Grid container direction='row' spacing={1} alignItems='center'>
                                                            <Grid item>
                                                                <SdCardIcon />
                                                            </Grid>
                                                            <Grid item>
                                                                <b>Tamanho: </b>{draft.attachments ? (draft.attachments[0].size / 1000000).toFixed(2) + ' Mb' : "Informação não disponível"}
                                                            </Grid>
                                                        </Grid>
                                                    </Grid>

                                                    <Grid item xs={12}>
                                                        <Grid container direction='row' spacing={1} alignItems='center'>
                                                            <Grid item>
                                                                <DateRangeIcon />
                                                            </Grid>
                                                            <Grid item>
                                                                <b>Enviado: </b>
                                                                {moment(draft.created_at).format("DD/MM/YYYY")}
                                                            </Grid>
                                                        </Grid>
                                                    </Grid>

                                                    <Grid item xs={12}>
                                                        <Grid container direction='row' spacing={1} alignItems='center'>
                                                            <Grid item>
                                                                <UpdateIcon />
                                                            </Grid>
                                                            <Grid item>
                                                                <b>Atualização: </b>
                                                                {moment(draft.updated_at).format("DD/MM/YYYY")}
                                                            </Grid>
                                                        </Grid>
                                                    </Grid>

                                                    <Grid item xs={12}>
                                                        {draft.language &&
                                                            draft.language.map((language =>
                                                                <Grid key={language.id} container direction='row' spacing={1} alignItems='center'>
                                                                    <Grid item>
                                                                        <TranslateIcon />
                                                                    </Grid>
                                                                    <Grid item>
                                                                        <b>Idioma: </b>{language.name}
                                                                    </Grid>
                                                                </Grid>
                                                            ))
                                                        }
                                                    </Grid>

                                                    <Grid item xs={12}>
                                                        <Grid container direction='row' spacing={1} alignItems='center'>
                                                            <Grid item>
                                                                <AssignmentIcon />
                                                            </Grid>
                                                            <Grid item>
                                                                <b>Licença: </b>{draft.license ? draft.license.name : "Informação não disponível"}

                                                            </Grid>
                                                        </Grid>
                                                    </Grid>
                                                </Grid>
                                            </Grid>
                                        </CaixaContainer>
                                    </MainContent>
                                    <MainContent contrast={props.contrast}>
                                        <CaixaContainer contrast={props.contrast} container spacing={2} justify='center' alignItems='center'>
                                            <Grid item xs={12} className='center'>
                                                <Grid container direction='row' alignItems='center' justify='space-between' >
                                                    <Grid item>
                                                        <h4>
                                                            Para segurança da plataforma marque que você não é um robô
                                                        </h4>
                                                    </Grid>
                                                    <Grid item>
                                                        <ReCaptcha sitekey="6LeIxAcTAAAAAJcZVRqyHh71UMIEGNQ_MXjiZKhI" verifyCallback={captchaVerified} />
                                                    </Grid>
                                                </Grid>

                                            </Grid>
                                            <Grid item xs={12} className='center'>
                                                <Grid container direction='row' spacing={1} alignItems='center' justify='center'>
                                                    <Grid item>
                                                        <GrayButton contrast={props.contrast} onClick={() => { props.stepperControl(-1) }}>VOLTAR</GrayButton>
                                                    </Grid>
                                                    <Grid item>
                                                        <GrayButton contrast={props.contrast} onClick={() => { toggleModalCancelar(true) }}>CANCELAR</GrayButton>
                                                    </Grid>
                                                    <Grid item>
                                                        {
                                                            checkAccessLevel("partner") ?
                                                                (
                                                                    unavailableButton ? (
                                                                        <GrayButton contrast={props.contrast} disabled={unavailableButton}>PUBLICAR RECURSO</GrayButton>
                                                                    )
                                                                        :
                                                                        (
                                                                            <OrangeButton contrast={props.contrast} onClick={props.handlePost}>PUBLICAR RECURSO</OrangeButton>
                                                                        )
                                                                )
                                                                :
                                                                (
                                                                    unavailableButton ? (
                                                                        <GrayButton contrast={props.contrast} disabled={unavailableButton}>SUBMETER RECURSO</GrayButton>
                                                                    )
                                                                        :
                                                                        (
                                                                            <OrangeButton contrast={props.contrast} onClick={props.handleSubmit}>SUBMETER RECURSO</OrangeButton>
                                                                        )
                                                                )

                                                        }
                                                    </Grid>
                                                </Grid>
                                            </Grid>
                                        </CaixaContainer>
                                    </MainContent>
                                </Grid>
                            </Grid>
                        </React.Fragment>
                    )
                    :
                    (
                        <LoadingSpinner text="CARREGANDO" contrast={props.contrast} />
                    )
            }
        </React.Fragment >
    )
}


const MainContent = styled.div`
    color: ${props => props.contrast === "" ? "#666" : "white"};
    border-radius : 5px;
    padding : 20px 10px;
    width: 80%;
    margin: 1.5em auto;
    border: ${props => props.contrast === "" ? "none" : "1px solid white"};
    box-shadow: 0 14px 28px rgba(0,0,0,0.25), 0 10px 10px rgba(0,0,0,0.22);
`

const CaixaContainer = styled(Grid)`
    width: 100%;
    
    .draft-info{
        padding : 10px 5px;
    }

    .tag{
        color: ${props => props.contrast === "" ? "black" : "white"};
        background: ${props => props.contrast === "" ? "#d4d4d4" : "black"};
        border: ${props => props.contrast === "" ? "none" : "1px solid white"}; 
        margin: 0.2em;
    }

    .title{
        text-align: center;
        font-weight: lighter;
    }

    .center{
        text-align: center;
    }
`

const StyledSessao1 = styled.div`
    color : #fff;
    background: ${props => props.contrast === "" ? "#00bcd4" : "black"};
    height : 300px;
    padding-top : 48px;
    padding-bottom : 48px;
    flex-direction : column;
    justify-content: center; 
    align-items: center;
    display: flex;

    .header{
        width: 50%;
        margin: 0 auto;
        text-align: center;
    }
`
