import React, { useState, useContext } from "react";
import { BackgroundDiv } from '../Components/TabPanels/StyledComponents.js'
import Paper from '@material-ui/core/Paper'
import styled from 'styled-components'
import FormInput from "../Components/FormInput.js"
import { CompletarCadastroButton } from '../Components/TabPanels/UserPageTabs/PanelSolicitarContaProfessor.js'
import ValidateUserInput from '../Components/HelperFunctions/FormValidationFunction.js'
import CustomizedBreadcrumbs from '../Components/TabPanels/Breadcrumbs.js'
import { putRequest } from '../Components/HelperFunctions/getAxiosConfig'
import Snackbar from '@material-ui/core/Snackbar'
import MuiAlert from '@material-ui/lab/Alert'
import Grid from '@material-ui/core/Grid'
import IconButton from '@material-ui/core/IconButton'
import VisibilityIcon from '@material-ui/icons/Visibility'
import VisibilityOffIcon from '@material-ui/icons/VisibilityOff'
import { Store } from '../Store'

function Alert(props) {
    return <MuiAlert elevation={6} variant="filled" {...props} />;
}

export default function ChangePasswordPage(props) {
    const { state } = useContext(Store)

    const [error, setError] = useState(false)
    const [success, setSuccess] = useState(false)
    const [time, setTime] = useState(5)

    const [formPassword, setPassword] = useState(
        {
            key: false,
            hidePass: true,
            value: ""
        }
    )

    const [formPasswordConfirmation, setPasswordConfirmation] = useState(
        {
            key: false,
            hidePass: true,
            value: ""
        }
    )

    const [snackInfo, setSnackInfo] = useState({
        open: false,
        text: "",
        severity: "",
    });

    const handleChange = (e, field) => {
        const userInput = e.target.value;
        const flag = ValidateUserInput('password', userInput);

        if (field === "password") {
            setPassword({
                ...formPassword,
                key: flag,
                value: userInput
            })
        } else {
            setPasswordConfirmation({
                ...formPasswordConfirmation,
                key: flag,
                value: userInput
            })
        }

    }

    const onSubmit = () => {
        const flag = ValidateUserInput('confirmation', formPassword.value, formPasswordConfirmation.value);

        if (flag === true) {
            const snackInfo = {
                open: true,
                text: "As senhas inseridas não são iguais",
                severity: "warning",
            }
            handleSnackInfo(snackInfo)
        } else {
            //console.log("senha bate");
            if (!formPassword.key && !formPasswordConfirmation.key) {
                console.log("senha bate");

                const urlParams = new URLSearchParams(window.location.search);
                const clientId = urlParams.get("client_id");
                const config = urlParams.get("config");
                const expiry = urlParams.get("expiry");
                const resetPassword = urlParams.get("reset_password");
                const token = urlParams.get("token");
                const uid = urlParams.get("uid");

                const url = `/auth/password`

                const payload = {
                    "password": formPassword.value,
                    "password_confirmation": formPasswordConfirmation.value,
                    "client": clientId,
                    "config": config,
                    "expiry": expiry,
                    "reset_password": resetPassword,
                    "access-token": token,
                    "uid": uid
                }

                putRequest(
                    url,
                    payload,
                    () => {
                        setSuccess(true)
                        let count = 0;
                        const snackInfo = {
                            open: true,
                            text: "Sua senha foi atualizada!",
                            severity: "success",
                        }
                        handleSnackInfo(snackInfo)
                        const intervalId = setInterval(() => {
                            count++;
                            setTime((previousTime) => previousTime - 1)
                            if (count === 5) {
                                window.location.href = "/"
                                clearInterval(intervalId)
                            }
                        }, 1000)
                    },
                    (error) => {
                        setError(true)
                        let count = 0;
                        const snackInfo = {
                            open: true,
                            text: "Houve um erro durante a requisição de troca de senha",
                            severity: "error",
                        }
                        handleSnackInfo(snackInfo)
                        const intervalId = setInterval(() => {
                            count++;
                            setTime((previousTime) => previousTime - 1)
                            if (count === 5) {
                                window.location.href = "/"
                                clearInterval(intervalId)
                            }
                        }, 1000)
                    }
                )
            }
        }
    }

    const handleSnackInfo = (info) => {
        setSnackInfo({ ...info })
    }

    const handleCloseSnack = () => {
        const snackInfo = {
            open: false,
            text: "",
            severity: "",
        }
        handleSnackInfo(snackInfo)
    }

    const handleStateHideFormPass = () => {
        setPassword({
            ...formPassword,
            hidePass: !formPassword.hidePass
        })
    }

    const handleStateHideConfFormPass = () => {
        setPasswordConfirmation({
            ...formPasswordConfirmation,
            hidePass: !formPasswordConfirmation.hidePass
        })
    }

    if (error)
        return (
            <BackgroundDiv contrast={state.contrast}>
                <Snackbar
                    open={snackInfo.open}
                    autoHideDuration={6000}
                    onClose={handleCloseSnack}
                    anchorOrigin={{ vertical: 'top', horizontal: 'right' }}
                >
                    <Alert onClose={handleCloseSnack} severity={snackInfo.severity}>
                        {snackInfo.text}
                    </Alert>
                </Snackbar>
                <div>
                    <CustomizedBreadcrumbs contrast={state.contrast}
                        values={["Recuperar senha", "Alterar senha"]}
                    />
                </div>
                <div style={{ justifyContent: "center", textAlign: "center", maxWidth: "600px", margin: "auto" }}>
                    <Paper elevation={3}>
                        <CardDiv contrast={state.contrast}>
                            <div style={{ overflow: "hidden", display: "inline-block" }}>
                                <h2 style={{ fontSize: "32px", fontWeight: "200", marginBottom: "20px", lineHeight: '35px' }}>
                                    Ocorreu um erro. Por favor, tente novamente mais tarde. Você será redirecionado para a home em... <StyledTimer>{time}</StyledTimer>
                                </h2>
                            </div>
                        </CardDiv>
                    </Paper>
                </div>
            </BackgroundDiv>
        )
    else if (success)
        return (
            <BackgroundDiv contrast={state.contrast}>
                <Snackbar
                    open={snackInfo.open}
                    autoHideDuration={6000}
                    onClose={handleCloseSnack}
                    anchorOrigin={{ vertical: 'top', horizontal: 'right' }}
                >
                    <Alert onClose={handleCloseSnack} severity={snackInfo.severity}>
                        {snackInfo.text}
                    </Alert>
                </Snackbar>
                <div>
                    <CustomizedBreadcrumbs contrast={state.contrast}
                        values={["Recuperar senha", "Alterar senha"]}
                    />
                </div>
                <div style={{ justifyContent: "center", textAlign: "center", maxWidth: "600px", margin: "auto" }}>
                    <Paper elevation={3}>
                        <CardDiv contrast={state.contrast}>
                            <div style={{ overflow: "hidden", display: "inline-block" }}>
                                <h2 style={{ fontSize: "32px", fontWeight: "200", marginBottom: "20px", lineHeight: '35px' }}>
                                    Sua senha foi alterada com sucesso. Você será redirecionado para a home em... <StyledTimer>{time}</StyledTimer>
                                </h2>
                            </div>
                        </CardDiv>
                    </Paper>
                </div>
            </BackgroundDiv>
        )
    else
        return (
            <BackgroundDiv contrast={state.contrast}>
                <Snackbar
                    open={snackInfo.open}
                    autoHideDuration={6000}
                    onClose={handleCloseSnack}
                    anchorOrigin={{ vertical: 'top', horizontal: 'right' }}
                >
                    <Alert onClose={handleCloseSnack} severity={snackInfo.severity}>
                        {snackInfo.text}
                    </Alert>
                </Snackbar>
                <div>
                    <CustomizedBreadcrumbs contrast={state.contrast}
                        values={["Recuperar senha", "Alterar senha"]}
                    />
                </div>
                <div style={{ justifyContent: "center", textAlign: "center", maxWidth: "600px", margin: "auto" }}>
                    <Paper elevation={3}>
                        <CardDiv contrast={state.contrast}>
                            <div style={{ overflow: "hidden", display: "inline-block" }}>
                                <h2 style={{ fontSize: "32px", fontWeight: "200", marginBottom: "20px" }}>Confirme a nova senha</h2>
                                <form onSubmit={(e) => { e.preventDefault(); onSubmit(e); }}>
                                    <Grid container direction='row' alignItems='center' spacing={1}>
                                        <Grid item xs={10}>
                                            <FormInput
                                                contrast={state.contrast}
                                                inputType={formPassword.hidePass ? "password" : ""}
                                                name={"senha"}
                                                value={formPassword.value}
                                                placeholder={"Senha"}
                                                handleChange={e => handleChange(e, 'password')}
                                                required={true}
                                                error={formPassword.key}
                                                help={formPassword.key ? (formPassword.value.length === 0 ? "Faltou digitar sua senha." : "A senha precisa ter no mínimo 8 caracteres.") : ""}
                                            />
                                        </Grid>
                                        <Grid item xs={2}>
                                            {
                                                formPassword.hidePass ?
                                                    <IconButton className={`${state.contrast}LinkColor`} onClick={handleStateHideFormPass}>
                                                        <VisibilityIcon />
                                                    </IconButton>
                                                    :
                                                    <IconButton className={`${state.contrast}LinkColor`} onClick={handleStateHideFormPass}>
                                                        <VisibilityOffIcon />
                                                    </IconButton>
                                            }
                                        </Grid>
                                    </Grid>
                                    <br />
                                    <Grid container direction='row' alignItems='center' spacing={1}>
                                        <Grid item xs={10}>
                                            <FormInput
                                                contrast={state.contrast}
                                                inputType={formPasswordConfirmation.hidePass ? "password" : ""}
                                                name={"confirme a senha"}
                                                value={formPasswordConfirmation.value}
                                                placeholder={"Confirme a senha"}
                                                handleChange={e => handleChange(e, 'confirmation')}
                                                required={true}
                                                error={formPasswordConfirmation.key}
                                                help={formPasswordConfirmation.key ? (formPasswordConfirmation.value.length === 0 ? "Faltou confirmar sua senha." : "A confirmação precisa ser igual a senha.") : ""}
                                            />
                                        </Grid>
                                        <Grid item xs={2}>
                                            {
                                                formPasswordConfirmation.hidePass ?
                                                    <IconButton className={`${state.contrast}LinkColor`} onClick={handleStateHideConfFormPass}>
                                                        <VisibilityIcon />
                                                    </IconButton>
                                                    :
                                                    <IconButton className={`${state.contrast}LinkColor`} onClick={handleStateHideConfFormPass}>
                                                        <VisibilityOffIcon />
                                                    </IconButton>
                                            }
                                        </Grid>
                                    </Grid>
                                    <div style={{ display: "flex", justifyContent: "center" }}>
                                        <CompletarCadastroButton contrast={state.contrast} type="submit" >ATUALIZAR SENHA</CompletarCadastroButton>
                                    </div>
                                </form>
                            </div>
                        </CardDiv>
                    </Paper>
                </div>
            </BackgroundDiv>
        )
}

const CardDiv = styled.div`
    color: ${props => props.contrast === "" ? "#666" : "white"} !important;
    text-decoration: ${props => props.contrast === "" ? "none" : "yellow underline"} !important;
    background-color: ${props => props.contrast === "" ? "white" : "black"} !important;
    border: ${props => props.contrast === "" ? "" : "1px solid white"} !important;

    box-shadow : 0 1px 3px rgba(0,0,0,.12),0 1px 2px rgba(0,0,0,.24);
    padding : 20px 30px;
    margin : 50px 0;
`
const StyledTimer = styled.span`
    color: #00bcd4;
`