import React, { useState, useContext } from 'react';
import styled from 'styled-components'
import Tabs from '@material-ui/core/Tabs'
import Tab from '@material-ui/core/Tab';
import Paper from '@material-ui/core/Paper';
import TabPanelEditarPerfil from '../Components/TabPanels/UserPageTabs/PanelEditarPerfil.js'
import TabPanelSolicitarContaProfessor from '../Components/TabPanels/UserPageTabs/PanelSolicitarContaProfessor.js'
import TabPanelGerenciarConta from '../Components/TabPanels/UserPageTabs/PanelGerenciarConta.js'
import Snackbar from '@material-ui/core/Snackbar';
import { Alert } from '../Components/LoginModal.js'
import Grid from '@material-ui/core/Grid'
import CustomizedBreadcrumbs from '../Components/TabPanels/Breadcrumbs.js'
import { putRequest } from '../Components/HelperFunctions/getAxiosConfig'
import { Store } from '../Store.js'

export default function EditProfilePage(props) {
    const { state, dispatch } = useContext(Store)
    const id = state.currentUser.id

    // eslint-disable-next-line
    const [tabs, setTabs] = useState([
        'Editar Perfil', 'Solicitar conta de Professor', 'Gerenciar Conta'
    ])
    const [tabValue, setTabValue] = useState(props.location.tabValue !== undefined ? props.location.tabValue.value : 0)
    const handleChangeTab = (e, newValue) => {
        setTabValue(newValue)
    }

    const [snackbarOpened, handleSnackbar] = useState({
        open: false,
        severity: "",
        text: ""
    })
    const handleCloseSnackbar = (event, reason) => {
        if (reason === 'clickaway') {
            return;
        }

        handleSnackbar({
            open: false,
            severity: "",
            text: ""
        });
    }

    const updateUserInfo = (newUserInfo) => {
        const url = `/users/${id}`

        putRequest(url, newUserInfo,
            (data) => { props.history.push('/perfil') },
            (error) => {
                handleSnackbar({
                    open: true,
                    severity: "error",
                    text: "Ocorreu um erro!"
                });
            }
        )
    }

    function handleSuccessUpdateEmail(data) {
        let auth_headers = JSON.parse(localStorage.getItem('@portalmec/auth_headers'))

        auth_headers['uid'] = data.uid

        localStorage.setItem('@portalmec/auth_headers', JSON.stringify(auth_headers))

        const target = state.currentUser
        const source = { uid: data.uid }

        handleSnackbar({
            open: true,
            severity: "success",
            text: "O email foi atualizado com sucesso!"
        });

        dispatch({
            type: 'USER_UPDATED_EMAIL',
            currUser: Object.assign(target, source)
        })
    }

    const updateUserEmail = (newUserInfo) => {
        const url = `/users/${id}`

        putRequest(
            url,
            newUserInfo,
            handleSuccessUpdateEmail,
            (error) => {
                handleSnackbar({
                    open: true,
                    severity: "error",
                    text: "Ocorreu um erro!"
                });
            }
        )
    }

    const updateUserPassword = (newUserInfo) => {
        const url = `/users/${id}`

        putRequest(url, newUserInfo,
            (data) => {
                handleSnackbar({
                    open: true,
                    severity: "success",
                    text: "A senha foi alterada com sucesso"
                });
            },
            (error) => {
                handleSnackbar({
                    open: true,
                    severity: "error",
                    text: "Ocorreu um erro!"
                });
            }
        )
    }

    return (
        <Main contrast={state.contrast}>
            <Snackbar open={snackbarOpened.open} autoHideDuration={1000} onClose={handleCloseSnackbar}
                anchorOrigin={{ vertical: 'top', horizontal: 'right' }}
            >
                <Alert severity={snackbarOpened.severity} >{snackbarOpened.text}</Alert>
            </Snackbar>

            <CustomizedBreadcrumbs
                contrast={state.contrast}
                values={["Minha área", "Configurações da Conta", tabs[tabValue]]}
            />

            <MainContainerDiv container spacing={3} justify="center" align="center">
                <Grid item xs={12} md={3} style={{ fontFamily: "Roboto" }} >
                    <Paper elevation={3}>
                        <ConfiguracoesMenu contrast={state.contrast}>
                            <h4 className="title">
                                Configurações da Conta
                            </h4>
                            <StyledTabs
                                contrast={state.contrast}
                                orientation="vertical"
                                variant="fullWidth"
                                textColor="primary"
                                value={tabValue}
                                onChange={handleChangeTab}
                                TabIndicatorProps={{ style: { display: "none" } }}
                            >
                                <StyledTab contrast={state.contrast} label={tabs[0]} />
                                <StyledTab contrast={state.contrast} label={tabs[1]} />
                                <StyledTab contrast={state.contrast} label={tabs[2]} />
                            </StyledTabs>
                        </ConfiguracoesMenu>
                    </Paper>
                </Grid>
                <TabContentDiv contrast={state.contrast} item xs={12} md={9}>
                    <Paper elevation={3} style={{ width: "100%" }}>
                        {tabValue === 0 && <TabPanelEditarPerfil updateUserInfo={updateUserInfo} />}
                        {tabValue === 1 && <TabPanelSolicitarContaProfessor />}
                    </Paper>
                    {tabValue === 2 && <TabPanelGerenciarConta updateUserEmail={updateUserEmail}
                        updateUserPassword={updateUserPassword}
                    />}
                </TabContentDiv>
            </MainContainerDiv>
        </Main>
    )
}

const Main = styled.div`
    background-color: ${props => props.contrast === "" ? "#f4f4f4" : "black"};
    color: ${props => props.contrast === "" ? "#666" : "white"};
`

const TabContentDiv = styled(Grid)`

    .subtitle{
        display: flex;
        justify-content: flex-start;
        font-size: 18px;
        color: ${props => props.contrast === "" ? "" : "white"};
    }

    .title{
        font-weight: 300; 
        color: ${props => props.contrast === "" ? "" : "white"};
    }
 
    .card-config {
        padding : 40px;
        margin : 20px 0 20px 10px;
        border-radius : 3px;
        box-shadow : 0 0 5px 0rgba(0,0,0,.25);
        background-color: ${props => props.contrast === "" ? "#fff" : "black"};
        border: ${props => props.contrast === "" ? 0 : "1px solid white"};
        text-align : start;
        margin-left : auto;
        margin-right : auto;
        display : flex;
        flex-direction : column;
    }

    .content-div {
        display : flex;
        flex-direction : column;
        align-content : stretch;
        align-items : stretch;
        font-family : 'Roboto', sans serif !important;
        font-size : 14px;
        justify-content : center;
        line-height : 20px;
        text-align : center;
        color : #666;
    }

    .h2 {
        margin-top : 20px;
        margin-bottom : 10px;
    }

    .p {
        margin : 0 0 10px;
    }

    .h1 {
        font-size : 30px;
        font-weight : 300;
        margin-top : 0;
        margin-bottom : 10px;
    }

    .h4 {
        font-size : 18px;
        margin-top : 10px;
        margin-bottom : 10px;
        font-weight : 500;
        line-height : 1.1;
    }

    .link {
        text-align: flex-start; 
        color: ${props => props.contrast === "" ? "#00bcd4" : "yellow"};
        text-decoration: ${props => props.contrast === "" ? "none" : "underline"}; 
    }
`

const StyledTabs = styled(Tabs)`
    display : flex;
    justify-content : center;
    .MuiTab-textColorPrimary{
        color: ${props => props.contrast === "" ? "#666" : "yellow"};
        text-decoration: ${props => props.contrast === "" ? "none" : "underline"};
        font-weight: 400; 
    }
    .MuiTab-textColorPrimary.Mui-selected {
        color: ${props => props.contrast === "" ? "black" : "yellow"};
        text-decoration: none; 
        font-weight: 600; 
    }
`

const StyledTab = styled(Tab)`
    &:hover {
        background-color: ${props => props.contrast === "" ? "#6666663d" : "rgba(255,255,0,0.24)"};
    }
`

const ConfiguracoesMenu = styled.div`
    margin : 20px 0 20px 0;
    border-radius : 3px;
    padding : 20px 0;
    background-color: ${props => props.contrast === "" ? "#fff" : "black"};
    border: ${props => props.contrast === "" ? 0 : "1px solid white"};

    .title{
        margin-top: 10px;
        font-family: inherit;
        display: flex;
        justify-content: center;
        color: ${props => props.contrast === "" ? "" : "white"};
    }
`

const MainContainerDiv = styled(Grid)`
    padding : 0;
    width : 90%;
    margin: 0 auto;
`
