import React, { useState, useContext } from 'react'
import { Store } from '../Store.js'
import Paper from '@material-ui/core/Paper';
import PartOne from '../Components/PageProfessorComponents/PartOne.js'
import PartTwo from '../Components/PageProfessorComponents/PartTwo.js'
import PartThree from '../Components/PageProfessorComponents/PartThree.js'
import SuccessfulRequest from '../Components/PageProfessorComponents/SuccessfulRequest.js'
import ModalConfirmarProfessor from '../Components/PageProfessorComponents/ModalConfirmarProfessor.js'
import { postRequest } from '../Components/HelperFunctions/getAxiosConfig'

export default function PageProfessor(props) {
    const { state } = useContext(Store)
    const [modalOpen, toggleModal] = useState(false)
    const handleModal = () => {
        toggleModal(!modalOpen);
    }

    const redirect = () => {
        props.history.push('/termos-publicar-recurso')
    }

    const [registerInformation, setRegisterInformation] = useState(
        {
            teacher_cpf: '',
            school_phone: '',
            school_name: '',
            school_city: '',
            school_uf: {
                abbreviation: '',
                name: ''
            },
            inep_code: ''
        }
    )

    const [activeStep, setActiveStep] = useState(0);

    const incrementStep = () => {
        setActiveStep((previous) => previous + 1);
    }

    const decrementStep = () => {
        setActiveStep((previous) => previous - 1);
    }

    const handleBuscarParteUm = (ufAbbreviation, ufName, nomeMunicipio, inep) => {
        setRegisterInformation({
            ...registerInformation,
            school_uf: {
                abbreviation: (ufAbbreviation ? ufAbbreviation : ''),
                name: (ufName ? ufName : '')
            },
            school_city: (nomeMunicipio ? nomeMunicipio : ''),
            inep_code: (inep ? inep : '')
        })
        incrementStep()
    }

    const handleBuscarParteDois = (city_name, inep, school_name, state_name) => {
        const uf_abbreviation = registerInformation.school_uf.abbreviation
        const prev_state_name = registerInformation.school_uf.name
        const prev_city_name = registerInformation.school_city.name

        setRegisterInformation({
            ...registerInformation,
            school_uf: {
                abbreviation: uf_abbreviation,
                name: (state_name ? state_name : prev_state_name)
            },
            school_city: (city_name ? city_name : prev_city_name),
            school_name: (school_name ? school_name : ''),
            inep_code: (inep ? inep : '')
        })
        incrementStep();
    }

    const handleParteTres = (phone, cpf) => {
        setRegisterInformation({
            ...registerInformation,
            teacher_cpf: (cpf ? cpf : ''),
            school_phone: (phone ? phone : ''),
        })
        handleModal();
    }

    const handleCancelar = () => {
        props.history.push('/perfil/atualizacoes')
    }

    function handleSuccessfulSubmit(data) {
        toggleModal()
        incrementStep();
    }

    const handleFinalSubmit = () => {
        const url = `/users/teacher_request`
        console.log(registerInformation)

        const payload = {
            city: registerInformation.school_city,
            cpf: registerInformation.teacher_cpf.toString(),
            inep_id: registerInformation.inep_code.toString(),
            phone: registerInformation.school_phone.toString(),
            school: registerInformation.school_name,
            uf: registerInformation.school_uf.name,
        }

        postRequest(url, payload, handleSuccessfulSubmit, (error) => { console.log(error) })
    }

    return (
        <>
            {
                state.userAgreedToPublicationTerms ?
                    (
                        <>
                            <ModalConfirmarProfessor contrast={props.contrast} open={modalOpen} handleClose={handleModal}
                                info={registerInformation} confirmar={() => { handleFinalSubmit() }}
                                cancelar={() => { toggleModal() }}
                            />
                            <div style={state.contrast === "" ? { backgroundColor: "#f4f4f4", color: "#666" } : { backgroundColor: "black", color: "white" }}>
                                <div style={{ display: "flex", justifyContent: "center", paddingTop: "5vh", paddingBottom: "5vh" }}>
                                    <Paper elevation={3} style={state.contrast === "" ? { width: "max-content" } : { width: "max-content", backgroundColor: "black", color: "white", border: '1px solid white' }}>
                                        <div style={{ paddingRight: "15px", paddingLeft: "15px" }}>
                                            {activeStep === 0 &&
                                                <PartOne contrast={state.contrast} activeStep={activeStep} handleBuscar={handleBuscarParteUm}
                                                    handleCancelar={handleCancelar}
                                                />
                                            }
                                            {activeStep === 1 &&
                                                <PartTwo activeStep={activeStep} contrast={state.contrast}
                                                    info={registerInformation} goBack={decrementStep}
                                                    handleCancelar={handleCancelar} handleBuscar={handleBuscarParteDois}
                                                />
                                            }
                                            {activeStep === 2 &&
                                                <PartThree activeStep={activeStep} goBack={decrementStep} contrast={state.contrast}
                                                    handleCancelar={handleCancelar} info={registerInformation}
                                                    handleSubmit={handleParteTres}
                                                />
                                            }
                                            {
                                                activeStep === 3 &&
                                                <SuccessfulRequest email={state.currentUser.email} history={props.history} contrast={state.contrast} />
                                            }
                                        </div>
                                    </Paper>
                                </div>
                            </div>
                        </>
                    )
                    :
                    (
                        <>
                            {redirect()}
                        </>
                    )
            }
        </>
    )
}
