/*Copyright (C) 2019 Centro de Computacao Cientifica e Software Livre
Departamento de Informatica - Universidade Federal do Parana

This file is part of Plataforma Integrada MEC.

Plataforma Integrada MEC is free software: you can redistribute it and/or modify
it under the terms of the GNU Affero General Public License as published by
the Free Software Foundation, either version 3 of the License, or
(at your option) any later version.

Plataforma Integrada MEC is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU Affero General Public License for more details.

You should have received a copy of the GNU Affero General Public License
along with Plataforma Integrada MEC.  If not, see <http://www.gnu.org/licenses/>.*/
import React, { useContext, useState } from 'react';
import { Store } from '../Store'
import styled from 'styled-components';
import Grid from '@material-ui/core/Grid';
import Fab from '@material-ui/core/Fab';
import { createMuiTheme, ThemeProvider } from '@material-ui/core/styles';

import { StyledButton } from '../Components/ButtonAvaliarRecurso.js';
import { BannerStyle } from './UserTerms';

/*Importação de imagens para o componente*/
import Handshake from "../img/termos/handshake.svg"
import Pessoa from "../img/termos/Pessoa.svg"
import Email from "../img/termos/Email.svg"
import Seguranca from "../img/termos/Seguranca.svg"
import Like from "../img/termos/Like.svg";
import Unlike from "../img/termos/Unlike.svg";
import Line from "../img/termos/Line.svg";

import ArrowDownwardIcon from '@material-ui/icons/ArrowDownward';
import ArrowUpwardIcon from '@material-ui/icons/ArrowUpward';
//Image Import
import { Aberto } from "ImportImages.js";
import { Fechado } from "ImportImages.js";

const theme = createMuiTheme({
    palette: {
        primary: {
            light: 'orange',
            main: 'orange',
            dark: 'orange',
            contrastText: '#fff',
        },
        secondary: {
            light: 'black',
            main: 'black',
            dark: 'black',
            contrastText: 'yellow',
        },
    },
  });
  

export default function SummarizedUserTerms() {
    const { state } = useContext(Store)
    const [slide, updateSlide] = useState(0);

    const handleGoUp = () => {
        console.log(slide - 1);
        if (slide > 1) {
            var element = document.getElementById("slide" + (slide - 1).toString());
            if (element.offsetHeight < state.windowSize.height) element.scrollIntoView({ behavior: 'smooth', block: 'center', inline: 'center' })
            else element.scrollIntoView({ behavior: 'smooth', block: 'start', inline: 'center' })
            updateSlide(slide - 1);
        } 
    }

    const handleGoDown = () => {
        if (slide < 7) {
            var element = document.getElementById("slide" + (slide + 1).toString());
            if (element.offsetHeight < state.windowSize.height) element.scrollIntoView({ behavior: 'smooth', block: 'center', inline: 'center' })
            else element.scrollIntoView({ behavior: 'smooth', block: 'start', inline: 'center' })
            updateSlide(slide + 1);
        } 
    }

    return (
        <Content contrast={state.contrast}>
            <link href="https://fonts.googleapis.com/css?family=Kalam|Pompiere|Roboto&display=swap" rel="stylesheet" />
            <BannerStyle contrast={state.contrast}>
                <h2 style={{ width: "100%", textAlign: "center", marginTop: "0px", paddingTop: "6rem", marginBottom: "16px", fontSize: "52px", fontFamily: "'Pompiere', cursive", color: "#fff", fontWeight: "500" }}>RESUMO DOS TERMOS DE USO</h2>
                <div style={{ display: "flex", justifyContent: "center" }}>
                    <StyledButton contrast={state.contrast} onClick={() => window.location.href='/termos'}>
                        Se preferir, veja a versão completa
                    </StyledButton>                    
                </div>  
            </BannerStyle>
            <FloatingButtons>
                <ThemeProvider theme={theme}>
                    <Fab
                        color={state.contrast === "" ? "primary": "secondary"}
                        aria-label="slide superior"
                        onClick={handleGoUp}
                        style={state.contrast === "" ? {} : {border: "1px solid white"}}
                    >
                        <ArrowUpwardIcon/>
                    </Fab>
                </ThemeProvider>
                <ThemeProvider theme={theme}>
                    <Fab
                        color={state.contrast === "" ? "primary": "secondary"}
                        aria-label="slide inferior"
                        onClick={handleGoDown}
                        style={state.contrast === "" ? {} : {border: "1px solid white"}}
                    >
                        <ArrowDownwardIcon/>
                    </Fab>
                </ThemeProvider>
            </FloatingButtons>
            <div className="slides">
                <div id="slide1" className="tmpl1">
                    <div className="container">
                        <Grid container>
                            <Grid item xs={12} md={8}>
                                <div className="box-text">
                                    <p>A Plataforma Integrada MEC RED é parte do Compromisso 6 do 3º Plano de Ação da Parceria para Governo Aberto (OGP-Brasil), que tem por objetivo “incorporar na política educacional o potencial da cultura digital, de modo a fomentar a autonomia para uso, reuso e adaptação de recursos educacionais digitais, valorizando a pluralidade e a diversidade da educação brasileira”.</p>
                                </div>
                            </Grid>
                            <Grid style={{ display: "flex", justifyContent: "center" }} item xs={12} md={4}>
                                <div className="box-image">
                                    <img src={Handshake} alt="handshake" />
                                </div>
                            </Grid>
                        </Grid>
                    </div>
                </div>
                <div id="slide2" className="tmpl2">
                    <div className="container">
                        <div className="title">
                            <p>O que é a Plataforma Integrada MEC RED e como ela está organizada?</p>
                        </div>
                        <Grid container>
                            <Grid className="box-text" item xs={12} md={6}>
                                <p>Uma plataforma interativa, colaborativa e criada em software livre, que disponibiliza conteúdos do acervo do MEC e indica conteúdos de parceiros com o objetivo de formar uma rede ativa de educadores interessados em usar, criar e compartilhar recursos educacionais digitais.</p>
                            </Grid>
                            <Grid className="box-text" item xs={12} md={6}>
                                <p><strong>Repositório</strong> de recursos educacionais digitais que permite aos usuários cadastrados a publicação de seus materiais e <strong>Referatório</strong> que aponta links para conteúdos em sites externos.</p>
                            </Grid>
                        </Grid>
                    </div>
                </div>
                <div id="slide3" className="tmpl3">
                    <div className="container">
                        <Grid className="title" container>
                            <Grid item xs={12}>
                                <p>Os recursos educacionais disponibilizados podem ser de dois tipos:</p>
                            </Grid>
                        </Grid>
                        <Grid container>
                            <Grid item xs={12} md={6}>
                                <div className="box-text">
                                    <img src={Aberto} alt="Aberto" />
                                    <p><strong>Abertos</strong>: recursos sem nenhuma restrição de acesso e<br /> com flexibilidade quanto ao uso ou reuso.</p>
                                </div>
                                <div className="box-text">
                                    <img src={Fechado} alt="Fechado" />
                                    <p><strong>Fechados</strong>: recursos com alguma restrição de acesso, uso<br /> ou reuso, como aqueles que, para acesso, há demanda de<br /> cadastro ou que têm licenças restritivas.</p>
                                </div>
                            </Grid>
                            <Grid item xs={12} md={6}>
                                <Grid item xs={12} md={12}>
                                    <div className="box-text">
                                        <p>Como repositório, a Plataforma hospeda somente Recursos Educacionais Abertos (REA). Todo conteúdo inserido por usuários deve ser aberto.</p>
                                    </div>
                                </Grid>
                                <Grid item xs={12} md={12}>
                                    <div className="box-text">
                                        <p>Como referatório, a Plataforma aponta links para parceiros, e<br /> esses recursos podem ser abertos ou fechados.</p>
                                    </div>
                                </Grid>
                            </Grid>
                        </Grid>
                    </div>
                </div>
                <div id="slide4" className="tmpl4">
                    <div className="container">
                        <Grid container>
                            <Grid item xs={12} md={6}>
                                <p className="title">Como se cadastrar?</p>
                                <div className="box-text">
                                    <p>Para criar uma conta, o usuário deverá clicar no botão “Cadastre-se” na página inicial da Plataforma e fazer um cadastro utilizando um endereço de e-mail e criando uma senha.</p>
                                </div>
                            </Grid>
                            <Grid item xs={4} md={2} style={{ alignSelf: "center" }}> <img style={{ width: "10vh", height: "10vh", verticalAlign: "middle", margin: "auto", display: "block" }} src={Pessoa} alt="Pessoa" /> </Grid>
                            <Grid item xs={4} md={2} style={{ alignSelf: "center" }}> <img style={{ width: "10vh", height: "10vh", verticalAlign: "middle", margin: "auto", display: "block" }} src={Email} alt="Email" /> </Grid>
                            <Grid item xs={4} md={2} style={{ alignSelf: "center" }}> <img style={{ width: "10vh", height: "10vh", verticalAlign: "middle", margin: "auto", display: "block" }} src={Seguranca} alt="Seguranca" /> </Grid>
                        </Grid>
                    </div>
                </div>
                <div id="slide5" className="tmpl5">
                    <div className="container">
                        <Grid container>
                            <Grid item xs={12} md={6}>
                                <div className="title">
                                    <img src={Like} alt="Like" />
                                    <p>O que publicar?</p>
                                </div>
                                <img src={Line} alt="Line" style={{margin: "auto", display: "block"}}/>
                                <div className="box-text">
                                    <p className="box-text">Conteúdos de cunho educacional e pertinentes ao assunto no qual estão inseridos, de autoria do usuário, de autoria coletiva (com consentimento dos demais autores) ou que estejam no domínio público. </p>
                                </div>
                            </Grid>
                            <Grid item xs={12} md={6}>
                                <div className="title">
                                    <img src={Unlike} alt="Unlike" />
                                    <p>O que não publicar?</p>
                                </div>
                                <img src={Line} alt="Line" style={{margin: "auto", display: "block"}}/>
                                <div className="box-text">
                                    <p className="box-text">Materiais ofensivos, pornográficos, relacionados a atividades ilegais, que invadam a privacidade de terceiros, que violem a legislação de Direito Autoral ou os Direitos Humanos. Propagandas, conteúdos com vírus, spam ou comentários abusivos.</p>
                                </div>
                            </Grid>
                        </Grid>
                    </div>
                </div>
                <div id="slide6" className="tmpl6">
                    <div className="container">
                        <Grid container>
                            <Grid item xs={12} md={7}>
                                <div className="title">
                                    <p>Direitos do autor e licenças de uso</p>
                                </div>
                                <div className="box-text">
                                    <p>Ao inserir um novo material de sua autoria no Repositório, o usuário deverá escolher um dos tipos de licença aberta disponíveis na Plataforma:</p>
                                </div>
                                <div className="box-text">
                                    <Grid container>
                                        <Grid item xs={3} className="licenses">
                                            <p>CC-BY</p>
                                        </Grid>
                                        <Grid item xs={3} className="licenses">
                                            <p>CC-BY-SA</p>
                                        </Grid>
                                        <Grid item xs={3} className="licenses">
                                            <p>CC-BY-NC</p>
                                        </Grid>
                                        <Grid item xs={3} className="licenses">
                                            <p>CC-BY-NC-SA</p>
                                        </Grid>
                                    </Grid>
                                </div>
                            </Grid>
                            <Grid item xs={12} md={5}>
                                <Grid container>
                                    <Grid item xs={12} md={2} className="licenses">
                                        <p>CC-BY</p>
                                    </Grid>
                                    <Grid item xs={12} md={10} className="box-text">
                                        <p> significa que o autor permite que distribuam, remixem, adaptem e criem a partir do seu trabalho, desde que lhe atribuam o devido crédito pela criação original</p>
                                    </Grid>
                                </Grid>
                                <Grid container>
                                    <Grid item xs={12} md={2} className="licenses">
                                        <p>NC</p>
                                    </Grid>
                                    <Grid item xs={12} md={10} className="box-text">
                                        <p> indica que as criações elaboradas a partir do trabalho do autor podem ser utilizadas somente para fins não comerciais (se não houver esta especificação, o novo recurso poderá ser utilizado para fins comerciais)</p>
                                    </Grid>
                                </Grid>
                                <Grid container>
                                    <Grid item xs={12} md={2} className="licenses">
                                        <p>SA</p>
                                    </Grid>
                                    <Grid item xs={12} md={10} className="box-text">
                                        <p> quer dizer que as novas criações devem ser licenciadas sob termos idênticos aos do trabalho original</p>
                                    </Grid>
                                </Grid>
                            </Grid>
                        </Grid>
                    </div>
                </div>
                <div id="slide7" className="tmpl7">
                    <div className="container">
                        <Grid container xs={12}>
                            <Grid className="title" item xs={12} md={6}>
                                <p>Respeitamos a sua privacidade</p>
                            </Grid>
                            <Grid item xs={12} md={6}>
                                <Grid item xs={12} md={12} className="box-text">
                                    <p>Além de solicitar alguns dados pessoais para o cadastro, a Plataforma coleta, de forma automática, os dados não pessoais relativos à interação dos usuários no sistema. Esses dados nunca serão fornecidos para fins comerciais, assim como nunca serão compartilhados quaisquer dados pessoais que possam identificar o usuário.</p>
                                </Grid>
                                <Grid item xs={12} md={12} className="box-text">
                                    <p>Os dados anônimos poderão ser utilizados para fins de melhoria da plataforma, transparência e para o uso em pesquisas.</p>
                                </Grid>
                            </Grid>
                        </Grid>
                        <Grid container xs={12}>
                            <div className="title">
                                <p>Dúvidas? Leia a <a href="/termos">versão completa dos termos de uso</a> ou fale conosco por meio do <a href="/contato">formulário de contato</a>.</p>
                            </div>
                        </Grid>
                    </div>
                </div>
            </div>
        </Content>
    )
}

const FloatingButtons = styled.div`
    display: flex;
    flex-direction: column;
	position: fixed !important;
    top: 50%;
    -ms-transform: translateY(-50%);
    transform: translateY(-50%);
    right: 15px;
    Fab {
        margin: 15px;
    }
`

const Content = styled.div`

    color: white;

    text-align: left;

    p {
        margin: 0;
    }

    a {
        text-decoration: ${props => props.contrast === "" ? "none" : "yellow underline"};
        color: ${props => props.contrast === "" ? "" : "yellow"};
    }

    .slides > div {
        min-height: 500px;
        display: flex;
        align-items: center;
        justify-content: center;
        border: 1px solid ${props => props.contrast === "" ? "inherit" : "white"};
        border-radius: 20px;
        margin: 25px;
    }

    .box-text {
        font-family: "Roboto", regular;
        display: flex;
        padding: 25px;
        img {
            width: 10vh;
            height: 10vh;
            vertical-align: middle;
        }
        font-size: 1.1em;
    }

    .title {
        font-family: "Pompiere", regular;
        padding: 25px;
        text-align: center;
        font-size: 3em;
    }

    .licenses {
        text-align: center; 
        margin: auto;
    }

    .box-image {

    }

    .tmpl1 {
        background: ${props => props.contrast === "" ? "#00BCD4" : "black"};
    }

    .tmpl2 {
        background: ${props => props.contrast === "" ? "#673AB7" : "black"};
    }

    .tmpl3 {
        background: ${props => props.contrast === "" ? "#E81F4F" : "black"};
    }

    .tmpl4 {
        background: ${props => props.contrast === "" ? "#FF7F00" : "black"};
    }

    .tmpl5 {
        background: ${props => props.contrast === "" ? "#1AB9DE" : "black"};
    }

    .tmpl6 {
        background: ${props => props.contrast === "" ? "#673AB7" : "black"};
    }

    .tmpl7 {
        background: ${props => props.contrast === "" ? "#E81F4F" : "black"};
    }
    
`