/*Copyright (C) 2019 Centro de Computacao Cientifica e Software Livre
Departamento de Informatica - Universidade Federal do Parana

This file is part of Plataforma Integrada MEC.

Plataforma Integrada MEC is free software: you can redistribute it and/or modify
it under the terms of the GNU Affero General Public License as published by
the Free Software Foundation, either version 3 of the License, or
(at your option) any later version.

Plataforma Integrada MEC is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU Affero General Public License for more details.

You should have received a copy of the GNU Affero General Public License
along with Plataforma Integrada MEC.  If not, see <http://www.gnu.org/licenses/>.*/

import React, { useState, useContext, useEffect } from "react";
import CustomizedBreadcrumbs from "../Components/TabPanels/Breadcrumbs.js";
import { Store } from "../Store.js";
import Tab from "@material-ui/core/Tab";
import ModalAlterarAvatar from "../Components/ModalAlterarAvatar/ModalAlterarAvatar";
import TabPanelAtividades from "../Components/TabPanels/UserPageTabs/PanelAtividades.js";
import TabPanelMeusRecursos from "../Components/TabPanels/UserPageTabs/PanelMeusRecursos.js";
import TabPanelFavoritos from "../Components/TabPanels/UserPageTabs/PanelFavoritos.js";
import TabPanelColecoes from "../Components/TabPanels/UserPageTabs/PanelColecoes.js";
import TabPanelRede from "../Components/TabPanels/UserPageTabs/PanelRede.js";
import TabPanelCuradoria from "../Components/TabPanels/UserPageTabs/PanelCuradoria.js";
import Grid from "@material-ui/core/Grid";
import {
    HeaderContainer,
    UserProfileContainer,
    CheckTeacherDiv,
    StyledTabs,
    RodapeDiv,
    NavBarContentContainer,
    BackgroundDiv,
} from "../Components/TabPanels/StyledComponents.js";
import Cover from "../Components/UserPageComponents/Cover.js";
import ProfileAvatar from "../Components/UserPageComponents/Avatar.js";
import UserInfo from "../Components/UserPageComponents/UserInfo.js";
import EditProfileButton from "../Components/UserPageComponents/EditProfileButton.js";
import SubmitterStatus from "../Components/UserPageComponents/SubmitterStatus.js";
import { getRequest } from "../Components/HelperFunctions/getAxiosConfig.js";
import Typography from "@material-ui/core/Typography";
import LoadingSpinner from '../Components/LoadingSpinner';

export default function UserPage(props) {
    const { state, dispatch } = useContext(Store);
    const id = state.currentUser.id;

    const [follows, setFollows] = useState(0);
    const [following, setFollowing] = useState(0);
    const [loading, setLoading] = useState(true);
    const [tabValue, setTabValue] = useState(Number(props.location.state) || 0);
    const [tabs, setTabs] = useState([
        "Atividades",
        "Meus Recursos",
        "Favoritos",
        "Coleções",
        "Rede",
    ]);
    const handleChangeTab = (event, newValue) => {
        setTabValue(newValue);
    };

    function handleSuccessfulGet(data) {
        dispatch({
            type: "GET_USER",
            user: data,
        });

        setFollows(data.follows_count);

        if (data.role_ids.includes(4)) {
            setTabs([
                "Atividades",
                "Meus Recursos",
                "Favoritos",
                "Coleções",
                "Rede",
                "Curadoria",
            ]);
        }
    }

    function handleSuccesGetFollowing(data) {
        setFollowing(data.length);
    }

    useEffect(() => {
        setLoading(true);
        if (id !== "") {
            const url = `/users/${id}`;
            const url2 = `/users/${id}/following/User`;
            getRequest(url, handleSuccessfulGet, (error) => {
                console.log(error);
            });
            getRequest(url2, handleSuccesGetFollowing, (error) => {
                console.log(error);
            });
        }
        setLoading(false);
    }, []);

    useEffect(() => {
        setTabValue(Number(props.location.state) || 0)
    }, [window.history.state.key])

    const redirect = () => {
        props.history.push("/");
    };

    const [modalOpen, toggleModal] = useState(false);
    const WIDTH = window.innerWidth;

    return (
        <div>
            <link
                href="https://fonts.googleapis.com/css?family=Roboto:100,400,500&display=swap"
                rel="stylesheet"
            />
            {
                loading ?
                (
                    <LoadingSpinner contrast={state.contrast} text="Carregando..." />
                )
                :
                (
                    state.userIsLoggedIn ? 
                    (
                        <React.Fragment>
                            <ModalAlterarAvatar
                                contrast={state.contrast}
                                open={modalOpen}
                                handleClose={() => {
                                    toggleModal(false);
                                }}
                                userAvatar={state.currentUser.avatar}
                            />
                            <BackgroundDiv contrast={state.contrast}>
                                <CustomizedBreadcrumbs contrast={state.contrast} values={["Minha área", tabs[tabValue]]} />
                                <Grid container spacing={2}>
                                    <Grid item xs={12}>
                                        <div style={{ padding: "10px 0 8px 0" }}>
                                            <UserProfileContainer>
                                                <HeaderContainer contrast={state.contrast}>
                                                    <Cover id={id} contrast={state.contrast}/>
                                                    <ProfileAvatar id={id} contrast={state.contrast}/>
                                                    {WIDTH <= 600 ? null : <UserInfo />}
                                                    <EditProfileButton contrast={state.contrast} />
                                                </HeaderContainer>
                                                {WIDTH <= 600 ? (
                                                <Grid
                                                    style={state.contrast === "" ? { marginTop: "4em" } : { paddingTop: "4em", backgroundColor: "black", borderLeft: "1px solid white", borderRight: "1px solid white", }}
                                                    container
                                                    justify="center"
                                                    alignItems="center"
                                                    direction="column"
                                                >
                                                    <Grid item>
                                                        <Typography
                                                            variant="h4"
                                                            gutterBottom
                                                            style={state.contrast === "" ? { textAlign: "center" } : { color: "white", textAlign: "center" }}
                                                        >
                                                            {state.currentUser.name}
                                                        </Typography>
                                                    </Grid>
                                                    <Grid
                                                        style={{
                                                            marginTop: "0.5em",
                                                            marginBottom: "0.5em",
                                                            borderTop: "1px solid white",
                                                            borderBottom: "1px solid white",
                                                        }}
                                                        container
                                                        spacing={4}
                                                        justify="center"
                                                        alignItems="center"
                                                        direction="row"
                                                    >
                                                        <Grid item>
                                                            <Typography style={state.contrast === "" ? {} : { color: "white" }} variant="h6" onClick={(e) => { handleChangeTab(e, 4) }}>
                                                                {follows} seguidores
                                                            </Typography>
                                                        </Grid>
                                                        <Grid item>
                                                            <Typography style={state.contrast === "" ? {} : { color: "white" }} variant="h6" onClick={(e) => { handleChangeTab(e, 4) }}>
                                                                {following} seguindo
                                                            </Typography>
                                                        </Grid>
                                                    </Grid>
                                                </Grid>
                                                ) : (
                                                    <CheckTeacherDiv contrast={state.contrast}>
                                                        <SubmitterStatus />
                                                    </CheckTeacherDiv>
                                                )}
                                                <RodapeDiv contrast={state.contrast}>
                                                    <NavBarContentContainer contrast={state.contrast}>
                                                        <StyledTabs
                                                            contrast={state.contrast}
                                                            value={tabValue}
                                                            onChange={handleChangeTab}
                                                            indicatorColor="primary"
                                                            textColor="primary"
                                                            variant="scrollable"
                                                            scrollButtons="on"
                                                            TabIndicatorProps={{ style: state.contrast === "" ? { background: "#00bcd4" } : { background: "yellow" } }}
                                                        >
                                                            {tabs.map((tab) => (
                                                                <Tab contrast={state.contrast} label={tab} key={tab} />
                                                            ))}
                                                        </StyledTabs>
                                                    </NavBarContentContainer>
                                                </RodapeDiv>
                                            </UserProfileContainer>
                                        </div>
                                    </Grid>
                                    <Grid item xs={12}>
                                        {tabValue === 0 && <TabPanelAtividades id={id} contrast={state.contrast} />}
                                        {tabValue === 1 && <TabPanelMeusRecursos id={id} contrast={state.contrast} />}
                                        {tabValue === 2 && <TabPanelFavoritos id={id} contrast={state.contrast} />}
                                        {tabValue === 3 && <TabPanelColecoes id={id} contrast={state.contrast} />}
                                        {tabValue === 4 && <TabPanelRede id={id} contrast={state.contrast} />}
                                        {tabValue === 5 && <TabPanelCuradoria id={id} contrast={state.contrast} />}
                                    </Grid>
                                </Grid>
                            </BackgroundDiv>
                        </React.Fragment>
                    )
                    :
                    (
                        <>
                            {redirect()}
                        </>
                    )
                )
            }
        </div>
    )
}
